@@ -88,7 +88,7 @@ BaseColorMapPlotCompositeWidget::~BaseColorMapPlotCompositeWidget()
 void
 BaseColorMapPlotCompositeWidget::createMainMenu()
 {
-  qDebug() << "Completing the main menu:" << mp_mainMenu;
+  // qDebug() << "Completing the main menu:" << mp_mainMenu;
 
   // Complete the base class menu with the color-map-specific menu
   // item.
