@@ -53,7 +53,6 @@
 #include "../nongui/MsRunDataSet.hpp"
 #include "../nongui/ProcessingFlow.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -63,51 +62,10 @@ class BaseColorMapPlotWnd;
 class MsFragmentationSpecDlg;
 class MzIntegrationParamsDlg;
 
-// The QWidgetAction strategy has too many problems,
-// in particular on macOS.
-// class DoubleSpinBoxLabelAction : public QWidgetAction
-//{
-// public:
-// DoubleSpinBoxLabelAction(QWidget *parent_p,
-// const QString &label,
-// const QString &tool_tip)
-//: QWidgetAction(parent_p)
-//{
-// QWidget *widget_p     = new QWidget(parent_p);
-// QHBoxLayout *layout_p = new QHBoxLayout();
-// mp_label              = new QLabel(label);
-// mp_label->setToolTip(tool_tip);
-// layout_p->addWidget(mp_label);
-// mp_spinBox = new QDoubleSpinBox(parent_p);
-// layout_p->addWidget(mp_spinBox);
-// widget_p->setLayout(layout_p);
-
-// setDefaultWidget(widget_p);
-//}
-
-// QDoubleSpinBox *
-// getSpinBox()
-//{
-// return mp_spinBox;
-//}
-
-// QLabel *
-// getLabel()
-//{
-// return mp_label;
-//}
-
-// private:
-// QDoubleSpinBox *mp_spinBox = nullptr;
-// QLabel *mp_label           = nullptr;
-//};
-
-
 // The BaseColorMapPlotCompositeWidget class is aimed at receiving QCPGraph_s,
 // not QCPColorMap_s. This class implements all the basic features related to
-// the presence of QCPGraph_s, like adding a Trace plot, for example, which
-// would not work if the plot were of type QCPColorMap...
-class BaseColorMapPlotCompositeWidget : public BasePlotCompositeWidget
+// the presence of QCPGraph_s, like adding a Colormap plot.
+class BaseColorMapPlotCompositeWidget: public BasePlotCompositeWidget
 {
   Q_OBJECT
 
@@ -137,16 +95,10 @@ class BaseColorMapPlotCompositeWidget : public BasePlotCompositeWidget
   bool saveMatrixAs3ColumnsToTextFile();
   bool saveMatrixAsMatrixToTextFile(bool detailed = false);
 
-  public slots:
-
-  void mainMenuPushButtonClicked();
-
-  signals:
-
   void plotWidgetMouseReleaseEventSignal(QMouseEvent *event);
 
   protected:
-  virtual void createMainMenu() override;
+  void createMainMenu() ;
 };
 
 
