@@ -167,7 +167,7 @@ BasePlotCompositeWidget::getParent()
 void
 BasePlotCompositeWidget::createMainMenu()
 {
-  // qDebug() << "ENTER";
+  // qDebug() << "BEGIN creating the main menu";
 
   // if(mp_mainMenu != nullptr)
   //   delete mp_mainMenu;
@@ -182,7 +182,7 @@ BasePlotCompositeWidget::createMainMenu()
   // Create the menu.
   mp_mainMenu = new QMenu(static_cast<QWidget *>(this));
 
-  qDebug() << "Created the main menu:" << mp_mainMenu;
+  // qDebug() << "Created the main menu:" << mp_mainMenu;
 
   // Create the menu push button.
   // const QIcon main_menu_icon =
@@ -327,7 +327,7 @@ BasePlotCompositeWidget::createMainMenu()
 
   mp_mainMenu->addMenu(mp_plotGraphicsMenu);
 
-  // qDebug() << "EXIT";
+  // qDebug() << "END creating the main menu:" << mp_mainMenu;
 }
 
 QFile *
@@ -661,7 +661,7 @@ BasePlotCompositeWidget::lastCursorHoveredPoint(const QPointF &pointf)
   QString style = QString("color: black");
   m_ui->statusLineEdit->setStyleSheet(style);
 
-  qDebug() << "point: (" << pointf.x() << "," << pointf.y() << ")";
+  // qDebug() << "point: (" << pointf.x() << "," << pointf.y() << ")";
 }
 
 void
@@ -964,7 +964,8 @@ BasePlotCompositeWidget::plottableToBeUsedAsIntegrationSource() const
 
   if(plottable_count == 1)
     {
-      qInfo() << "Only a plottable is plotted, this is going to be the source ";
+      // qDebug()
+      //   << "Only a plottable is plotted, this is going to be the source ";
 
       return mp_plotWidget->plottable();
     }
@@ -1002,16 +1003,16 @@ BasePlotCompositeWidget::plottablesToBeUsedAsIntegrationDestination() const
   // will be the destination.
 
   QList<QCPAbstractPlottable *> plottable_list;
-  int graph_count = mp_plotWidget->graphCount();
+  int plottable_count = mp_plotWidget->plottableCount();
 
-  if(!graph_count)
+  if(!plottable_count)
     {
-      // Not a single graph in the widget.
+      // Not a single plottable in the widget.
     }
-  else if(graph_count == 1)
+  else if(plottable_count == 1)
     {
-      // Only one graph in the widget.
-      plottable_list.append(mp_plotWidget->graph());
+      // Only one plottable in the widget.
+      plottable_list.append(mp_plotWidget->plottable(0));
     }
   else
     {
