@@ -220,6 +220,34 @@ BasePlotWnd::initialize()
   mp_vertRuleSlider->setMinimum(1);
   mp_vertRuleSlider->setMaximum(mp_centralWidget->size().width());
 
+#if 0
+// We want to be certain that there is no gap between the left side of
+// the rectanble of these three widgets, because we need to make some
+// calculations for the slider handle position.
+
+  if(mp_scrollArea->rect().left() != mp_vertRuleSlider->rect().left())
+    qDebug() << "The difference is:"
+             << mp_vertRuleSlider->rect().left() - mp_scrollArea->rect().left();
+  else
+    qDebug() << "There is no difference:"
+             << mp_vertRuleSlider->rect().left() - mp_scrollArea->rect().left();
+
+
+  if(mpa_plotAreaOverlay->rect().left() != mp_vertRuleSlider->rect().left())
+    qDebug() << "The difference is:"
+             << mp_vertRuleSlider->rect().left() -
+                  mpa_plotAreaOverlay->rect().left();
+  else
+    qDebug() << "There is no difference:"
+             << mp_vertRuleSlider->rect().left() -
+                  mpa_plotAreaOverlay->rect().left();
+
+  if(mpa_plotAreaOverlay->rect().width() != mp_vertRuleSlider->rect().width())
+    qFatal() << "Not the same:"
+             << mpa_plotAreaOverlay->rect().width() -
+                  mp_vertRuleSlider->rect().width();
+#endif
+
   // Start hidden.
   mp_vertRuleSlider->setVisible(m_isLockedYMarker);
 
@@ -229,7 +257,7 @@ BasePlotWnd::initialize()
   connect(mp_vertRuleSlider,
           &VerticalRuleSlider::sliderHandleCenterPositionXChangedSignal,
           this,
-          &BasePlotWnd::verticalRuleSliderValueChanged);
+          &BasePlotWnd::verticalRuleSliderHandleRectCenterXValueChanged);
 
   readSettings();
 
@@ -237,78 +265,128 @@ BasePlotWnd::initialize()
 }
 
 void
-BasePlotWnd::verticalRuleSliderValueChanged(int x_position)
+BasePlotWnd::verticalRuleSliderHandleRectCenterXValueChanged(int x_position)
 {
-  // The user has modified the position of the slider, which means we need to
-  // update the position of the vertical rule that spans all the composite plot
-  // widgets that lie below.
 
-  // qDebug() << "The vertical ruler slide has value:" << value;
+  // qDebug()
+  //   << "New vertical rule slider handle center point x-axis value (pixels):"
+  //   << x_position;
 
-  // We need the plot-overlay-widget to know the current value of the slider,
-  // that represents the position of the vertical ruler. Using the new value,
-  // the update call below will plot the vertical line at the right position.
+  // The user has modified the position of the slider.
+  // The slider itself has computed the position of the center point of the
+  // slider handle and emitted a signal with the x() of that center point. This
+  // is what we get here, as a pixel value within the referential of the whole
+  // slider rectangle (that is, starting from x=0 being the left side of that
+  // rectangle).
 
+  // Draw the line at this handle center x position.
   mpa_plotAreaOverlay->setLastHorSliderValue(x_position);
-  qDebug() << "Now setting the last horizontal slider value to" << x_position;
 
-  // There is one provision: if the plot widgets in this plot window are locked
-  // in their x-axis, then we want to show on the slider handle the x-axis
-  // value that it is hovering over.
+  // There are two situations:
+  // 1. The user has not locked the plot widgets along the x-axis. In this case,
+  // we do only draw the vertical rule at the new position.
 
-  if(m_isLockedXRange)
-    {
-      // qDebug() << "The XRange is locked.";
-
-      // We want to display the x-axis value on the rule vertical slider handle.
-      // Get the list of plot composite widgets that are in this window.
-
-      QList<BasePlotCompositeWidget *> widget_list =
-        findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
-
-      // If there are not plot composite widgets, there are not plottables
-      // (traces) there, and thus not x-axis value. Return.
-      if(!widget_list.size())
-        return;
-
-      BasePlotCompositeWidget *composite_widget_p = widget_list.first();
-      Q_ASSERT(composite_widget_p != nullptr);
-
-      // Iterate down from window coordinates to x-axis coordinates!
-
-      // First the composite widget coordinates:
-      QPointF composite_widget_coord =
-        composite_widget_p->mapFromParent(QPointF(x_position, 0));
-      // qDebug() << "composite_widget_coord_x:" << composite_widget_coord.x();
-
-      // Then the plot widget coordinates:
-      QPointF widget_coord = composite_widget_p->getPlotWidget()->mapFromParent(
-        composite_widget_coord);
-      // qDebug() << "widget_coord_x:" << widget_coord.x();
-
-      double x_axis_coordinate =
-        composite_widget_p->getPlotWidget()->xAxis->pixelToCoord(
-          widget_coord.x());
-      // qDebug() << "Plot widget xAxis x:" << x_axis_coordinate;
-
-#if 0
-      // This produces the same result as the above call.
-      QCPAbstractPlottable *plottable_p =
-        composite_widget_p->plottableToBeUsedAsIntegrationSource();
-      double coord_x = 0;
-      double coord_y = 0;
-      plottable_p->pixelsToCoords(widget_coord.x(), 0, coord_x, coord_y);
-      qDebug() << qSetRealNumberPrecision(5)
-               << "Plottable x:" << coord_x;
-#endif
-
-      mp_vertRuleSlider->updatePosLabelXaxisValue(x_axis_coordinate);
-    }
-  else
+  if(!m_isLockedXRange)
     {
       mp_vertRuleSlider->setXposLabelVisible(false);
+      mpa_plotAreaOverlay->update();
+      return;
     }
 
+  // 2. The user has locked the plot widgets along the x-axis. In this case,
+  // we also need to draw a label next to the slider handle to display the
+  // x-axis position of the vertical rule. The x-axis value that we want to
+  // print in the label needs to be computed starting from the pixel x position
+  // of the center point of the rectangle of the slider handle:
+
+  /*
+  |------------0
+  */
+
+  // This is the slider, with the dot in the O being the center of the handle
+  // of which we get the x_position.
+  // That x_position is relative to the left side of the rectangle in which
+  // the whole slider is packed.
+
+  // Because the slider is packed in this plot window along with the
+  // custom plot widgets, we need to see if these two widgets are aligned
+  // on their left side. To check this, get the left rectangle of each
+  // widget, get the left side x value in screen coordinates and compare.
+  // In fact, we know they are not aligned, because the slider widget has its
+  // enclosing rectangle left side right at the left border of this window,
+  // while the c
+
+  // The slider coordinates
+  QRect global_slider_rect(mp_vertRuleSlider->mapToGlobal(QPoint(0, 0)),
+                           mp_vertRuleSlider->size());
+  // qDebug() << "mp_vertRuleSlider rect" << mp_vertRuleSlider->rect()
+  //          << "global:" << global_slider_rect;
+  // ======> mp_vertRuleSlider rect QRect(0,0 1232x20) global: QRect(2574,818
+  // 1232x20)
+
+  // Get the list of plot composite widgets that are in this window.
+  QList<BasePlotCompositeWidget *> widget_list =
+    findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
+
+  // If there are not plot composite widgets, there are not plottables
+  // (traces) there, and thus not x-axis value. Return.
+  if(!widget_list.size())
+    return;
+
+  // The composite plot widget coordinates
+  BasePlotCompositeWidget *composite_widget_p = widget_list.first();
+  Q_ASSERT(composite_widget_p != nullptr);
+  QRect global_composite_plot_widget_rect(
+    composite_widget_p->mapToGlobal(QPoint(0, 0)), composite_widget_p->size());
+  // qDebug() << "composite_widget_p rect" << composite_widget_p->rect()
+  //          << "global:" << global_composite_plot_widget_rect;
+  // composite_widget_p rect QRect(0,0 1195x472) global: QRect(2582,852
+  // 1195x472)
+
+  // The QCustomplot widget coordinates
+  QRect global_qcustomplot_widget_rect(
+    composite_widget_p->getPlotWidget()->mapToGlobal(QPoint(0, 0)),
+    composite_widget_p->getPlotWidget()->size());
+  // qDebug() << "qcustomplot widget rect"
+  //          << composite_widget_p->getPlotWidget()->axisRect()->rect()
+  //          << "global:" << global_qcustomplot_widget_rect;
+  // qcustomplot widget rect QRect(33,15 1012x363) global: QRect(2658,875
+  // 1060x424)
+
+  // See what offset there is between the left side of the rectangles that
+  // contain each one of the three widgets above:
+
+  // In screen coordinates, the qcustomplot widget' left side is right of the
+  // the slider widget's left side: so the offset is positive here, all we will
+  // remove it from the position used for converting pixels to x-axis values
+  // below.
+  double x_axis_offset =
+    global_qcustomplot_widget_rect.x() - global_slider_rect.x();
+  // qDebug() << qSetRealNumberPrecision(5) << "The offset is:" <<
+  // x_axis_offset;
+
+  // So we see that there is an x_axis_offset of 84 px difference between the
+  // left side of the slider rectangle and the left side of the qcustomplot
+  // widget.
+
+  double x_axis_coordinate =
+    composite_widget_p->getPlotWidget()->xAxis->pixelToCoord(x_position -
+                                                             x_axis_offset);
+  // qDebug() << qSetRealNumberPrecision(5)
+  //          << "Plot widget xAxis x:" << x_axis_coordinate;
+
+#if 0
+  // This produces the same result as the above call.
+  QCPAbstractPlottable *plottable_p =
+    composite_widget_p->plottableToBeUsedAsIntegrationSource();
+  double coord_x = 0;
+  double coord_y = 0;
+  plottable_p->pixelsToCoords(x_position - x_axis_offset, 0, coord_x, coord_y);
+  qDebug() << qSetRealNumberPrecision(5) << "Plottable x:" << coord_x;
+#endif
+
+  mp_vertRuleSlider->updatePosLabelXaxisValue(x_axis_coordinate);
+
   // Now that the new position at which the rule needs to be drawn, we can
   // update the widget so that it repaints itself, thus drawing the vertical
   // line at the right position.
@@ -374,10 +452,8 @@ BasePlotWnd::setupToolBar()
   mp_lockXRangeAct->setCheckable(true);
   mp_lockXRangeAct->setShortcut(QKeySequence("Ctrl+L, X"));
   mp_lockXRangeAct->setStatusTip(tr("Lock X range"));
-
   connect(
     mp_lockXRangeAct, &QAction::toggled, this, &BasePlotWnd::lockXRangeToggle);
-
   mp_toolBar->addAction(mp_lockXRangeAct);
 
   const QIcon yRangeIcon = QIcon(":/images/svg/lock-y-range.svg");
@@ -386,7 +462,6 @@ BasePlotWnd::setupToolBar()
   mp_lockYRangeAct->setCheckable(true);
   mp_lockYRangeAct->setShortcut(QKeySequence("Ctrl+L, Y"));
   mp_lockYRangeAct->setStatusTip(tr("Lock Y range"));
-
   connect(
     mp_lockYRangeAct, &QAction::toggled, this, &BasePlotWnd::lockYRangeToggle);
 
@@ -398,7 +473,6 @@ BasePlotWnd::setupToolBar()
   mp_lockYMarkerAct->setCheckable(true);
   mp_lockYMarkerAct->setShortcut(QKeySequence("Ctrl+L, W"));
   mp_lockYMarkerAct->setStatusTip(tr("Lock multi-widget Y marker"));
-
   connect(mp_lockYMarkerAct,
           &QAction::toggled,
           this,
@@ -437,6 +511,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   mp_mainMenuToolButton->setToolTip(action_p->text());
   // When the main menu push button is clicked, the menu shows up.
@@ -465,6 +540,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(isActiveWindow())
@@ -481,6 +557,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(isActiveWindow())
@@ -517,11 +594,12 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
 
   // Lambda function to compute the right size for each plot widget in the
   // splitter.
-  connect(mp_resetPlotSizesAct, &QAction::triggered, this, [&]() {
+  connect(action_p, &QAction::triggered, this, [&]() {
     if(!isActiveWindow())
       return;
 
@@ -556,6 +634,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(!isActiveWindow())
@@ -574,6 +653,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(!isActiveWindow())
@@ -597,6 +677,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(!isActiveWindow())
@@ -615,6 +696,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(!isActiveWindow())
@@ -635,6 +717,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(!isActiveWindow())
@@ -650,6 +733,7 @@ BasePlotWnd::createMainMenu()
   action_id.initialize("Global", "Menus", "PlotWindow", action_label);
   action_p = program_window_p->getActionManager()->installAction(action_id,
                                                                  key_sequence);
+  Q_ASSERT(action_p != nullptr);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
     if(!isActiveWindow())
@@ -701,7 +785,7 @@ BasePlotWnd::createMainMenu()
                                                                  key_sequence);
   this->addAction(action_p);
   connect(action_p, &QAction::triggered, this, [&]() {
-    qDebug() << "Trigger.";
+    // qDebug() << "Trigger.";
 
     if(!isActiveWindow())
       return;
@@ -754,7 +838,7 @@ BasePlotWnd::mzIntegrationParamsChanged(
 
       for(int iter = 0; iter < destination_plottables.size(); ++iter)
         {
-          QCPAbstractPlottable *iter_plottable_p =
+          const QCPAbstractPlottable *iter_plottable_p =
             destination_plottables.at(iter);
 
           // Now get the ProcessingFlow for the plottable:
@@ -859,7 +943,7 @@ BasePlotWnd::msFragmentationSpecChanged(
 
       for(int iter = 0; iter < destination_plottables.size(); ++iter)
         {
-          QCPAbstractPlottable *iter_plottable_p =
+          const QCPAbstractPlottable *iter_plottable_p =
             destination_plottables.at(iter);
 
           // Now get the ProcessingFlow for the plottable:
@@ -1306,7 +1390,6 @@ BasePlotWnd::lockXRangeToggle(bool checked)
 {
   m_isLockedXRange = checked;
   // qDebug() << "Is the lockXRange check button checked?:" << m_isLockedXRange;
-  mp_vertRuleSlider->computeHandlePosition();
   mp_vertRuleSlider->setXposLabelVisible(m_isLockedXRange);
 }
 
@@ -1324,7 +1407,6 @@ BasePlotWnd::lockYMarkerToggle(bool checked)
   m_isLockedYMarker = checked;
   mpa_plotAreaOverlay->setVertRuleVisible(m_isLockedYMarker);
   mp_vertRuleSlider->setVisible(m_isLockedYMarker);
-  mp_vertRuleSlider->computeHandlePosition();
   // Only show the x axis value in the label if we are in locked X range mode.
   if(m_isLockedXRange)
     mp_vertRuleSlider->updatePosLabelXaxisValue();
