@@ -54,6 +54,7 @@
 
 /////////////////////// libXpertMassGui includes
 #include <MsXpS/libXpertMassGui/LabelledNumberLineEditAction.hpp>
+#include <MsXpS/libXpertMassGui/LabelledCheckBoxAction.hpp>
 
 
 /////////////////////// Local includes
@@ -153,7 +154,7 @@ BaseTracePlotCompositeWidget::~BaseTracePlotCompositeWidget()
 void
 BaseTracePlotCompositeWidget::createMainMenu()
 {
-  qDebug() << "Completing the main menu:" << mp_mainMenu;
+  // qDebug() << "BEGIN extending the main menu:" << mp_mainMenu;
 
   // Complete the base class menu with the trace specific menu item.
 
@@ -162,29 +163,99 @@ BaseTracePlotCompositeWidget::createMainMenu()
   QPixmap pixmap = the_icon.pixmap(size);
   pixmap.save("/tmp/basetraceploticon.png");
 
-  QAction *save_peak_list_to_clipboard_p =
-    new QAction("Save peak list to clipboard", this);
-  save_peak_list_to_clipboard_p->setStatusTip(
-    tr("Save peak list to clipboard"));
-  save_peak_list_to_clipboard_p->setShortcut(QKeySequence("Ctrl+P, C"));
+  ProgramWindow *program_window_p =
+    static_cast<Application *>(qApp)->getProgramWindow();
 
-  connect(save_peak_list_to_clipboard_p, &QAction::triggered, [this]() {
-    savePeakListToClipboard();
-  });
+  QString action_label;
+  libXpertMassGui::ActionId action_id;
+  QKeySequence key_sequence;
+  // Action to be gottent for action_id.
+  QAction *action_p              = nullptr;
+  // Store for later if an action by action_id was already registered.
+  QAction *pre_existing_action_p = nullptr;
 
-  mp_mainMenu->addAction(save_peak_list_to_clipboard_p);
+  // Save peak list sub menu to hold check box option and the relevant menu
+  // items.
+  QMenu *save_peak_list_menu_p = mp_mainMenu->addMenu("Save peak list");
 
-  QAction *save_peak_list_to_file_p =
-    new QAction("Save peak list to file", this);
-  save_peak_list_to_file_p->setStatusTip(tr("Save peak list to file"));
-  save_peak_list_to_file_p->setShortcut(QKeySequence("Ctrl+P, C"));
+  QWidgetAction *peak_list_save_mode_action_p =
+    new libXpertMassGui::LabelledCheckBoxAction(
+      "Check to only save visible data range",
+      Qt::CheckState::Unchecked,
+      "" /*no text here*/,
+      dynamic_cast<QObject *>(this));
+  save_peak_list_menu_p->addAction(peak_list_save_mode_action_p);
+  connect(static_cast<libXpertMassGui::LabelledCheckBoxAction *>(
+            peak_list_save_mode_action_p),
+          &libXpertMassGui::LabelledCheckBoxAction::checkBoxStateToggledSignal,
+          this,
+          &BaseTracePlotCompositeWidget::
+            savePeakListOnlyForVisibleRangeCheckBoxStateChanged);
 
-  connect(save_peak_list_to_file_p, &QAction::triggered, [this]() {
-    savePeakListToFile();
-  });
-
-  mp_mainMenu->addAction(save_peak_list_to_file_p);
+  action_label = "Save peak list to clipboard";
+  action_id.initialize(
+    "Plot1D", "CompositePlotWidget", "Analysis", action_label);
+  // Store for later if an action by action_id was already registered.
+  pre_existing_action_p =
+    program_window_p->getActionManager()->getAction(action_id);
+  // If an action by action_id preexisted, its pointer would be returned
+  // without a new allocation. Thus, if more than one base trace
+  // composite plot widgets are created, they would have a connection
+  // below multiple times against the very same QAction. This is not possible,
+  // which is why we check for a potentially existing QACtion by action_id.
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+P, C"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  action_p->setToolTip("Save peak list to clipboard");
+  save_peak_list_menu_p->addAction(action_p);
+  // We may call this code a large number of times: each time a new
+  // trace plot widget is called, an we do not want that the same QAction *
+  // be connected innumerous times, because the corresponding menu action
+  // when triggered will be repeated as many times.
+  // Only connect if no action by action_id has been allocated before.
+  if(pre_existing_action_p != nullptr)
+    {
+      connect(action_p, &QAction::triggered, this, [this]() {
+        qDebug()
+          << "Save peak list to clipboard - in the lambda  with only visible:"
+          << this->m_isSavePeakListOnlyForVisibleRange;
+        BaseTracePlotCompositeWidget::savePeakListToClipboard(
+          this->m_isSavePeakListOnlyForVisibleRange /*only_in_current_range*/);
+      });
+    }
 
+  action_label = "Save peak list to file";
+  action_id.initialize(
+    "Plot1D", "CompositePlotWidget", "Analysis", action_label);
+  // Store for later if an action by action_id was already registered.
+  pre_existing_action_p =
+    program_window_p->getActionManager()->getAction(action_id);
+  // If an action by action_id preexisted, its pointer would be returned
+  // without a new allocation. Thus, if more than one base trace
+  // composite plot widgets are created, they would have a connection
+  // below multiple times against the very same QAction. This is not possible,
+  // which is why we check for a potentially existing QACtion by action_id.
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+P, F"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  action_p->setToolTip("Save peak list to file");
+  save_peak_list_menu_p->addAction(action_p);
+  // We may call this code a large number of times: each time a new
+  // trace plot widget is called, an we do not want that the same QAction *
+  // be connected innumerous times, because the corresponding menu action
+  // when triggered will be repeated as many times.
+  // Only connect if no action by action_id has been allocated before.
+  if(pre_existing_action_p != nullptr)
+    {
+      connect(action_p, &QAction::triggered, this, [this]() {
+        qDebug() << "Save peak list to file - in the lambda  with only visible:"
+                 << this->m_isSavePeakListOnlyForVisibleRange;
+        BaseTracePlotCompositeWidget::savePeakListToFile(
+          this->m_isSavePeakListOnlyForVisibleRange /*only_in_current_range*/);
+      });
+    }
   mp_mainMenu->addSeparator();
 
   QMenu *integrations_menu_p = mp_mainMenu->addMenu("&Integrations");
@@ -199,6 +270,7 @@ BaseTracePlotCompositeWidget::createMainMenu()
 
   connect(single_point_integration_mode_action_p,
           &QAction::triggered,
+          this,
           [this, single_point_integration_mode_action_p]() {
             m_isSinglePointIntegrationMode =
               single_point_integration_mode_action_p->isChecked();
@@ -210,10 +282,11 @@ BaseTracePlotCompositeWidget::createMainMenu()
 
   QMenu *filters_menu_p = mp_mainMenu->addMenu("&Filters");
 
-  // We want to provide the user with the ability to define a noise sample. They
-  // would create a new graph by integrating to that new graph with combination
-  // the various regions they feel are noise. They would get a noise sample
-  // trace. Then they'd call the menu below to store that trace for further use.
+  // We want to provide the user with the ability to define a noise
+  // sample. They would create a new graph by integrating to that new
+  // graph with combination the various regions they feel are noise.
+  // They would get a noise sample trace. Then they'd call the menu
+  // below to store that trace for further use.
 
   QMenu *noise_handling_menu_p = filters_menu_p->addMenu("Noise handling");
 
@@ -239,8 +312,8 @@ BaseTracePlotCompositeWidget::createMainMenu()
 
   filters_menu_p->addSeparator();
 
-  // Savitzky-Golay filtering: two submenus: one to parameterize and the other
-  // to actually run the filter.
+  // Savitzky-Golay filtering: two submenus: one to parameterize and the
+  // other to actually run the filter.
 
   QMenu *savgol_filter_menu_p = filters_menu_p->addMenu("&Savitzky-Golay");
 
@@ -250,9 +323,10 @@ BaseTracePlotCompositeWidget::createMainMenu()
     "Configure Savitzky-Golay smoothing filter");
   savitzky_golay_config_filter_action_p->setShortcut(QKeySequence("Ctrl+S, C"));
 
-  connect(savitzky_golay_config_filter_action_p, &QAction::triggered, [this]() {
-    showSavitzkyGolayFilterParamsDlg();
-  });
+  connect(
+    savitzky_golay_config_filter_action_p, &QAction::triggered, this, [this]() {
+      showSavitzkyGolayFilterParamsDlg();
+    });
 
   savgol_filter_menu_p->addAction(savitzky_golay_config_filter_action_p);
 
@@ -262,9 +336,10 @@ BaseTracePlotCompositeWidget::createMainMenu()
     "Run Savitzky-Golay smoothing filter");
   savitzky_golay_run_filter_action_p->setShortcut(QKeySequence("Ctrl+S, R"));
 
-  connect(savitzky_golay_run_filter_action_p, &QAction::triggered, [this]() {
-    runSavitzkyGolayFilter();
-  });
+  connect(
+    savitzky_golay_run_filter_action_p, &QAction::triggered, this, [this]() {
+      runSavitzkyGolayFilter();
+    });
 
   savgol_filter_menu_p->addAction(savitzky_golay_run_filter_action_p);
 
@@ -280,9 +355,10 @@ BaseTracePlotCompositeWidget::createMainMenu()
       true,
       dynamic_cast<QObject *>(this));
   widget_action_p->setStatusTip("Remove signal below the provided threshold");
-  connect(widget_action_p, &QAction::triggered, [this, widget_action_p]() {
-    runLowIntensityThresholdRemovalFilter(widget_action_p);
-  });
+  connect(
+    widget_action_p, &QAction::triggered, this, [this, widget_action_p]() {
+      runLowIntensityThresholdRemovalFilter(widget_action_p);
+    });
   filters_menu_p->addAction(widget_action_p);
 
 
@@ -295,6 +371,8 @@ BaseTracePlotCompositeWidget::createMainMenu()
           this,
           &BaseTracePlotCompositeWidget::removeZeroIntensityDataPointsFilter);
   filters_menu_p->addAction(filter_high_pass_0_action_p);
+
+  // qDebug() << "END extending the main menu:" << mp_mainMenu;
 }
 
 void
@@ -1158,6 +1236,11 @@ BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(
       // function call.
     }
 
+  if(context.m_pressedKeyCode == Qt::Key_Delete)
+    {
+      qDebug() << "Qt::Key_Delete";
+    }
+
   // We do not call the stanza recording function because that will be
   // performed by the derived classes when all the chances of having filled-in
   // the fields have been met.
@@ -1167,6 +1250,8 @@ void
 BaseTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
   const pappso::BasePlotContext &context)
 {
+  // qDebug() << "m_plotWidgetReleasedKeyCode:" << m_plotWidgetReleasedKeyCode;
+
   BasePlotCompositeWidget::plotWidgetKeyReleaseEvent(context);
 
   // The F3 key triggers the displacement of the mouse cursor to the next
@@ -1506,6 +1591,22 @@ BaseTracePlotCompositeWidget::pinPointPeakApexCheckBoxStateChanged(
     }
 }
 
+void
+BaseTracePlotCompositeWidget::
+  savePeakListOnlyForVisibleRangeCheckBoxStateChanged(Qt::CheckState state)
+{
+  qDebug() << "with check state:" << state;
+
+  if(state == Qt::Checked)
+    {
+      m_isSavePeakListOnlyForVisibleRange = true;
+    }
+  else if(state == Qt::Unchecked || state == Qt::PartiallyChecked)
+    {
+      m_isSavePeakListOnlyForVisibleRange = false;
+    }
+}
+
 void
 BaseTracePlotCompositeWidget::createLabellingSessionMenu()
 {
@@ -1782,9 +1883,21 @@ BaseTracePlotCompositeWidget::pickPeaksOnlyOnVisibleMaxima()
 }
 
 bool
-BaseTracePlotCompositeWidget::savePeakListToClipboard()
+BaseTracePlotCompositeWidget::savePeakListToClipboard(
+  bool only_in_visible_range)
 {
-  // qDebug();
+  // This slot is activated when a QAction is triggered. That unique
+  // QAction might be referenced multiple times in various menus
+  // inside various base trace plot composite widgets from various
+  // plot windows. We thus need
+  // to only act if the trigger is while this widget is actually focussed and
+  // the window that contains it is actually active.
+  if(!static_cast<QWidget *>(parent())->isActiveWindow() || !isFocussed())
+    return false;
+
+  qDebug() << "Only visible range:" << only_in_visible_range;
+  qDebug() << "Member only visible range:"
+           << m_isSavePeakListOnlyForVisibleRange;
 
   // Check first how many plottables there are in the widget.
 
@@ -1807,9 +1920,10 @@ BaseTracePlotCompositeWidget::savePeakListToClipboard()
 
   pappso::Trace trace =
     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
-      ->toTrace(source_graph_p);
+      ->toTrace(source_graph_p, only_in_visible_range);
 
   QString trace_string = trace.toString();
+  // qDebug().noquote() << "The trace is:" << trace_string;
 
   QClipboard *clipboard_p = QApplication::clipboard();
 
@@ -1819,9 +1933,18 @@ BaseTracePlotCompositeWidget::savePeakListToClipboard()
 }
 
 bool
-BaseTracePlotCompositeWidget::savePeakListToFile()
+BaseTracePlotCompositeWidget::savePeakListToFile(bool only_in_visible_range)
 {
-  // qDebug();
+  // This slot is activated when a QAction is triggered. That unique
+  // QAction might be referenced multiple times in various menus
+  // inside various base trace plot composite widgets from various
+  // plot windows. We thus need
+  // to only act if the trigger is while this widget is actually focussed and
+  // the window that contains it is actually active.
+  if(!static_cast<QWidget *>(parent())->isActiveWindow() || !isFocussed())
+    return false;
+
+  qDebug() << "Only visible range:" << only_in_visible_range;
 
   QString file_name = QFileDialog::getSaveFileName(
     this, tr("Export to text file"), QDir::homePath(), tr("Any file type(*)"));
@@ -1850,7 +1973,9 @@ BaseTracePlotCompositeWidget::savePeakListToFile()
 
   pappso::Trace trace =
     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
-      ->toTrace(source_graph_p);
+      ->toTrace(source_graph_p, only_in_visible_range);
+
+  // qDebug().noquote() << "The trace is:" << trace.toString();
 
   return pappso::Utils::writeToFile(trace.toString(), file_name);
 }
