@@ -230,13 +230,8 @@ BaseTracePlotWnd::finalNewTracePlotConfiguration(
 
   connect(composite_widget_p->getPlotWidget(),
           &pappso::BasePlotWidget::plottableDestructionRequestedSignal,
-          [composite_widget_p, this](
-            [[maybe_unused]] const pappso::BasePlotWidget *base_plot_widget_p,
-            QCPAbstractPlottable *plottable_p,
-            const pappso::BasePlotContext &context) {
-            mp_programWindow->plottableDestructionRequested(
-              composite_widget_p, plottable_p, context);
-          });
+          this,
+          &BaseTracePlotWnd::requestPlottableDestruction);
 
   //////// CAUTION ///////
   //////// CAUTION ///////
@@ -276,6 +271,22 @@ BaseTracePlotWnd::finalNewTracePlotConfiguration(
   return graph_p;
 }
 
+void
+BaseTracePlotWnd::requestPlottableDestruction(
+  const pappso::BasePlotWidget *base_plot_widget_p,
+  QCPAbstractPlottable *plottable_p,
+  const pappso::BasePlotContext &context)
+{
+  // We first need to get the pointer to the composite plot widget
+  // that contains the pappso::BasePlotWidget.
+
+  BaseTracePlotCompositeWidget *composite_widget_p =
+    dynamic_cast<BaseTracePlotCompositeWidget *>(base_plot_widget_p->parent());
+
+  mp_programWindow->plottableDestructionRequested(
+    composite_widget_p, plottable_p, context);
+}
+
 QCPGraph *
 BaseTracePlotWnd::duplicateTracePlot(
   const BaseTracePlotCompositeWidget *composite_widget_p)
