@@ -48,7 +48,6 @@
 
 /////////////////////// Local includes
 #include "DriftSpecTracePlotCompositeWidget.hpp"
-#include "DriftSpecTracePlotWidget.hpp"
 #include "DriftSpecTracePlotWnd.hpp"
 #include "ui_BasePlotCompositeWidget.h"
 
@@ -168,8 +167,8 @@ DriftSpecTracePlotCompositeWidget::moveMouseCursorToNextGraphPoint(
 
   pappso::BasePlotContext local_context;
   local_context.initialize(context);
-  local_context.m_xRegionRangeStart     = m_integrationRange.lower;
-  local_context.m_xRegionRangeEnd       = m_integrationRange.upper;
+  local_context.m_xRegionRangeStart = m_integrationRange.lower;
+  local_context.m_xRegionRangeEnd   = m_integrationRange.upper;
 
   if(m_isSinglePointIntegrationMode)
     integrationRequested(local_context);
@@ -202,11 +201,11 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       //**local_context.msp_integrationScope->convertTo1D();
       double width;
       if(!local_context.msp_integrationScope->getWidth(width))
-        qFatal("Failed to get width.");
+        qFatal() << "Failed to get width.";
 
       QPointF point;
       if(!local_context.msp_integrationScope->getPoint(point))
-        qFatal("Failed to get point.");
+        qFatal() << "Failed to get point.";
 
       local_context.msp_integrationScope =
         std::make_shared<const pappso::IntegrationScopeBase>(
@@ -312,8 +311,10 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
 
   // It is essential that we document the relation between the axes and the
   // corresponding data type.
-  processing_step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::dt);
-  processing_step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::unset);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x,
+                                  pappso::Enums::DataKind::dt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y,
+                                  pappso::Enums::DataKind::unset);
 
   if(m_ui->integrateToRtPushButton->isChecked())
     {
@@ -448,7 +449,8 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
       temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, nullptr, *temp_processing_flow_p);
+        ->integrateToTicIntensity(
+          plottable_p, nullptr, *temp_processing_flow_p);
     }
   else
     {
@@ -462,7 +464,7 @@ DriftSpecTracePlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::NoButton);
     }
 
-    delete temp_processing_flow_p;
+  delete temp_processing_flow_p;
 
   return;
 }
@@ -477,8 +479,8 @@ DriftSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   // char was pressed.
   BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(context);
 
-  // qDebug() << "After filling-in by base class, the stanza is:"
-  //<< m_analysisStanza;
+  qDebug() << "After filling-in by base class, the stanza is:"
+           << m_analysisStanza;
 
   m_plotWidgetPressedKeyCode = context.m_pressedKeyCode;
 
@@ -527,207 +529,18 @@ QString
 DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
   const pappso::BasePlotContext &context)
 {
-  // qDebug();
+  Q_UNUSED(context)
 
-  QCPAbstractPlottable *plottable_p = plottableToBeUsedAsIntegrationSource();
+  // qDebug().noquote() << "With context:" << context.toString();
+  // qDebug().noquote()
+  // << "We get from the base class stanza work the following text:"
+  // << m_analysisStanza;
 
-  if(plottable_p == nullptr)
-    {
-      // We should inform the user if there are more than one plottable.
+  // Since this class has no specialized data, apart those already handled
+  // in the base class function, all we need to do is return the stanza that
+  // has already been crafted by the base class.
 
-      int plottable_count = mp_plotWidget->plottableCount();
-
-      if(plottable_count > 1)
-        {
-          QMessageBox::information(
-            this,
-            "Crafting an analysis stanza for a graph",
-            "Please select a single trace and try again.");
-        }
-
-      m_analysisStanza = "";
-      return QString();
-    }
-
-  MsRunDataSetCstSPtr ms_run_data_set_csp =
-    getCstProcessingFlowPtrForPlottable(plottable_p)->getMsRunDataSetCstSPtr();
-
-  QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
-
-  // Craft the analysis stanza by copying the m_analysisStanza that was
-  // partially filled-in by the base classes and go on filling-in fields still
-  // marked with "%<char>" format patterns.
-
-  QString orig_stanza = m_analysisStanza;
-  QString stanza;
-
-  QChar prevChar = ' ';
-
-  for(int iter = 0; iter < orig_stanza.size(); ++iter)
-    {
-      QChar curChar = orig_stanza.at(iter);
-
-      // qDebug() << "Current char:" << curChar;
-
-      if(curChar == '\\')
-        {
-          if(prevChar == '\\')
-            {
-              stanza   += '\\';
-              prevChar  = ' ';
-              continue;
-            }
-          else
-            {
-              prevChar = '\\';
-              continue;
-            }
-        }
-
-      if(curChar == '%')
-        {
-          if(prevChar == '\\')
-            {
-              stanza   += '%';
-              prevChar  = ' ';
-              continue;
-            }
-          else
-            {
-              prevChar = '%';
-              continue;
-            }
-        }
-
-      if(curChar == 'n')
-        {
-          if(prevChar == '\\')
-            {
-              stanza += QString("\n");
-
-              // Because a newline only works if it is followed by something,
-              // and
-              // if the user wants a termination newline, then we need to
-              // duplicate that new line char if we are at the end of the
-              // string.
-
-              if(iter == orig_stanza.size() - 1)
-                {
-                  // This is the last character of the line, then, duplicate
-                  // the
-                  // newline so that it actually creates a new line in the
-                  // text.
-
-                  stanza += QString("\n");
-                }
-
-              prevChar = ' ';
-              continue;
-            }
-        }
-
-      if(prevChar == '%')
-        {
-          // The current character might have a specific signification.
-          if(curChar == 'f')
-            {
-              QFileInfo fileInfo(sample_name);
-              if(fileInfo.exists())
-                stanza += fileInfo.fileName();
-              else
-                stanza += "Untitled";
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 's')
-            {
-              QFileInfo fileInfo(sample_name);
-              if(fileInfo.exists())
-                stanza += fileInfo.fileName();
-              else
-                stanza += "Untitled";
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'X')
-            {
-              stanza += QString("%1").arg(
-                context.m_lastCursorHoveredPoint.x(), 0, 'g', 6);
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'Y')
-            {
-              // We need to get the value of the intensity for the graph, but
-              // not as an integration to INT, but simply as the y coordinate
-              // of the point at X.
-              stanza += QString("%1").arg(
-                static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
-                  ->getYatX(context.m_lastCursorHoveredPoint.x(),
-                            static_cast<QCPGraph *>(plottable_p)),
-                0,
-                'g',
-                6);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'x')
-            {
-              stanza   += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
-              prevChar  = ' ';
-              continue;
-            }
-          if(curChar == 'y')
-            {
-              stanza += QString("%1").arg(context.m_yDelta, 0, 'g', 6);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'I')
-            {
-              stanza += QString("%1").arg(m_lastTicIntensity, 0, 'g', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'b')
-            {
-              stanza +=
-                QString("%1").arg(context.m_xRegionRangeStart, 0, 'f', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'e')
-            {
-              stanza += QString("%1").arg(context.m_xRegionRangeEnd, 0, 'f', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          // At this point the '%' is not followed by any special character
-          // above, so we skip them both from the text. If the '%' is to be
-          // printed, then it needs to be escaped. We do this because we do not
-          // expect that derived classes will do the format-based field-filling
-          // work later.
-
-          continue;
-        }
-      // End of
-      // if(prevChar == '%')
-
-      // The character prior this current one was not '%' so we just append
-      // the current character.
-      stanza += curChar;
-    }
-  // End of
-  // for (int iter = 0; iter < pattern.size(); ++iter)
-
-  // Finally copy the result into the member datum.
-  m_analysisStanza = stanza;
-  return stanza;
+  return m_analysisStanza;
 }
 
 
