@@ -52,7 +52,6 @@
 #include "TaskMonitorCompositeWidget.hpp"
 #include "TaskMonitorWnd.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -67,13 +66,11 @@ DriftSpecTracePlotWnd::DriftSpecTracePlotWnd(QWidget *parent,
 {
 }
 
-
 //! Destruct \c this DriftSpecTracePlotWnd instance.
 DriftSpecTracePlotWnd::~DriftSpecTracePlotWnd()
 {
 }
 
-
 QCPGraph *
 DriftSpecTracePlotWnd::addTracePlot(
   const pappso::Trace &trace,
@@ -106,7 +103,6 @@ DriftSpecTracePlotWnd::addTracePlot(
     composite_widget_p, trace, processing_flow, color, parent_plottable_p);
 }
 
-
 void
 DriftSpecTracePlotWnd::integrateToDt(
   QCPAbstractPlottable *parent_plottable_p,
@@ -122,7 +118,7 @@ DriftSpecTracePlotWnd::integrateToDt(
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
@@ -132,7 +128,7 @@ DriftSpecTracePlotWnd::integrateToDt(
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
 
   if(!integration_rt)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug() << qSetRealNumberPrecision(10)
   //          << "Innermost RT range:" << range_pair.first << "-"
@@ -157,7 +153,8 @@ DriftSpecTracePlotWnd::integrateToDt(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
   // qDebug()
-  //   << "The number of selected mass spectra on the basis of rough RT/DT values:"
+  //   << "The number of selected mass spectra on the basis of rough RT/DT
+  //   values:"
   //   << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
@@ -316,7 +313,6 @@ DriftSpecTracePlotWnd::integrateToDt(
                &MassDataIntegratorTask::integrateToDt));
 }
 
-
 void
 DriftSpecTracePlotWnd::finishedIntegratingToDt(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
@@ -398,23 +394,21 @@ DriftSpecTracePlotWnd::finishedIntegratingToDt(
       showWindow();
     }
 
-    delete temp_processing_flow_p;
+  delete temp_processing_flow_p;
 }
 
-
 void
 DriftSpecTracePlotWnd::integrateToRt(QCPAbstractPlottable *parent_plottable_p,
                                      const ProcessingFlow &processing_flow)
 {
-  qDebug();
+  // qDebug();
 
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToRt(parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 DriftSpecTracePlotWnd::integrateToMz(QCPAbstractPlottable *parent_plottable_p,
                                      const ProcessingFlow &processing_flow)
@@ -422,12 +416,11 @@ DriftSpecTracePlotWnd::integrateToMz(QCPAbstractPlottable *parent_plottable_p,
   // qDebug();
 
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToMz(parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 DriftSpecTracePlotWnd::integrateToDtMz(QCPAbstractPlottable *parent_plottable_p,
                                        const ProcessingFlow &processing_flow)
@@ -435,7 +428,7 @@ DriftSpecTracePlotWnd::integrateToDtMz(QCPAbstractPlottable *parent_plottable_p,
   // qDebug();
 
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   // We do not handle integrations to dt, because each trace plot window
   // handles their own data. So we just relay this call to the main program
@@ -445,7 +438,6 @@ DriftSpecTracePlotWnd::integrateToDtMz(QCPAbstractPlottable *parent_plottable_p,
     parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 DriftSpecTracePlotWnd::integrateToMzRt(QCPAbstractPlottable *parent_plottable_p,
                                        const ProcessingFlow &processing_flow)
@@ -453,13 +445,12 @@ DriftSpecTracePlotWnd::integrateToMzRt(QCPAbstractPlottable *parent_plottable_p,
   // qDebug();
 
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToMzRt(
     parent_plottable_p, nullptr, processing_flow);
 }
 
-
 void
 DriftSpecTracePlotWnd::integrateToDtRt(QCPAbstractPlottable *parent_plottable_p,
                                        const ProcessingFlow &processing_flow)
@@ -467,7 +458,7 @@ DriftSpecTracePlotWnd::integrateToDtRt(QCPAbstractPlottable *parent_plottable_p,
   // qDebug();
 
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToDtRt(
     parent_plottable_p, nullptr, processing_flow);
