@@ -47,6 +47,10 @@
 #include <pappsomspp/core/trace/datapoint.h>
 #include <pappsomspp/gui/plotwidget/massspectraceplotwidget.h>
 
+
+/////////////////////// libXpertMassCore
+#include <MsXpS/libXpertMassCore/LowMassDeconvolver.hpp>
+
 /////////////////////// Local includes
 #include "BaseTracePlotCompositeWidget.hpp"
 
@@ -81,19 +85,22 @@ class MassSpecTracePlotCompositeWidget: public BaseTracePlotCompositeWidget
   plotWidgetKeyPressEvent(const pappso::MassSpecTracePlotContext &context);
 
   virtual void
-  plotWidgetMousePressEvent(const pappso::MassSpecTracePlotContext &context);
+  plotWidgetKeyReleaseEvent(const pappso::BasePlotContext &context)override;
 
   virtual void
-  plotWidgetMouseReleaseEvent(const pappso::MassSpecTracePlotContext &context);
+  plotWidgetMousePressEvent(const pappso::MassSpecTracePlotContext &context) ;
+
+  virtual void
+  plotWidgetMouseReleaseEvent(const pappso::MassSpecTracePlotContext &context) ;
 
   virtual void moveMouseCursorToNextGraphPoint(
     const pappso::BasePlotContext &context) override;
 
-  virtual void
-  plotWidgetKeyReleaseEvent(const pappso::BasePlotContext &context) override;
   void integrationRequested(const pappso::BasePlotContext &context);
 
   void gaussianFitOnVisibleMaxima();
+  pappso::Trace extractAndDisplayCentroids();
+  std::vector<libXpertMassCore::DeconvolutedFeature> lowMassDeconvolve();
 
   virtual QCPGraph *addTrace(const pappso::Trace &trace,
                              QCPAbstractPlottable *parent_plottable_p,
@@ -102,13 +109,24 @@ class MassSpecTracePlotCompositeWidget: public BaseTracePlotCompositeWidget
                              const ProcessingFlow &processing_flow,
                              const QColor &color) override;
 
+  virtual QCPBars *addBars(const pappso::Trace &trace,
+                             QCPAbstractPlottable *parent_plottable_p,
+                             MsRunDataSetCstSPtr ms_run_data_set_csp,
+                             const QString &sample_name,
+                             const ProcessingFlow &processing_flow,
+                             const QColor &color);
+
   void setMinimalChargeFractionalPartPinnedDownWidgets(double value);
   void setChargeStateEnvelopePeakSpanPinnedDownWidgets(std::size_t value);
 
+  void
+  peakPickDeconvOnlyForVisibleRangeCheckBoxStateChanged(Qt::CheckState state);
+
   signals:
 
   protected:
-   void createMainMenu() ;
+  bool m_isPeakPickDeconvOnlyForVisibleRange = false;
+  virtual void createMainMenu() override;
 
   QString craftAnalysisStanza(const pappso::MassSpecTracePlotContext &context);
 
