@@ -114,28 +114,30 @@ MassSpecTracePlotWnd::extendMainMenu()
     "Set the charge minimal fractional part for all pinned-down widget "
     "(typically 0.99)");
 
-  connect(
-    mp_setMinimalChargeFractionalPartAction, &QAction::triggered, [this]() {
-      bool ok = false;
+  connect(mp_setMinimalChargeFractionalPartAction,
+          &QAction::triggered,
+          this,
+          [this]() {
+            bool ok = false;
 
-      double charge_minimal_fractional_part = QInputDialog::getDouble(
-        this,
-        "Set the charge minimal fractional part",
-        "Charge (z) minimal fractional part (typically 0.99)",
-        m_minimalFractionalPart,
-        0.5,
-        0.9999,
-        4,
-        &ok);
+            double charge_minimal_fractional_part = QInputDialog::getDouble(
+              this,
+              "Set the charge minimal fractional part",
+              "Charge (z) minimal fractional part (typically 0.99)",
+              m_minimalFractionalPart,
+              0.5,
+              0.9999,
+              4,
+              &ok);
 
-      if(ok)
-        {
-          m_minimalFractionalPart = charge_minimal_fractional_part;
+            if(ok)
+              {
+                m_minimalFractionalPart = charge_minimal_fractional_part;
 
-          setMinimalChargeFractionalPartPinnedDownWidgets(
-            m_minimalFractionalPart);
-        }
-    });
+                setMinimalChargeFractionalPartPinnedDownWidgets(
+                  m_minimalFractionalPart);
+              }
+          });
 
   mp_deconvolutionsMenu->addAction(mp_setMinimalChargeFractionalPartAction);
 
@@ -145,7 +147,7 @@ MassSpecTracePlotWnd::extendMainMenu()
     "Set the span between two peaks of a charge state envelope (typically 1 or "
     "2)");
 
-  connect(mp_setMassPeakSpanAction, &QAction::triggered, [this]() {
+  connect(mp_setMassPeakSpanAction, &QAction::triggered, this, [this]() {
     bool ok = false;
 
     double peak_span = QInputDialog::getInt(
@@ -172,9 +174,74 @@ MassSpecTracePlotWnd::extendMainMenu()
   mp_mainMenu->addSeparator();
 }
 
-// This function does not check if there are widgets that are pinned-down so as
-// to gather new trace data. This function creates a brand new plot composite
-// widget.
+void
+MassSpecTracePlotWnd::keyPressEvent(QKeyEvent *event)
+{
+  // qDebug() << "Key press event:" << event->key();
+
+  if(event->key() == Qt::Key_Delete)
+    {
+      // qDebug() << "Key: Key_Delete";
+    }
+}
+
+void
+MassSpecTracePlotWnd::keyReleaseEvent(QKeyEvent *event)
+{
+  // qDebug() << "Key press event:" << event->key();
+
+  if(event->key() == Qt::Key_Delete)
+    {
+      // qDebug() << "Key: Key_Delete";
+
+      // Get the composite plot widget that has the focus.
+      std::vector<BasePlotCompositeWidget *> all_widgets = allWidgets();
+
+      // qDebug() << "There are " << all_widgets.size()
+      //          << "base plot composite widgets.";
+
+      BasePlotCompositeWidget *focussed_widget_p = nullptr;
+
+      for(std::size_t iter = 0; iter < all_widgets.size(); ++iter)
+        {
+          if(all_widgets.at(iter)->isFocussed())
+            {
+              focussed_widget_p = all_widgets.at(iter);
+              break;
+            }
+        }
+
+      Q_ASSERT(focussed_widget_p != nullptr);
+
+      QList<QCPAbstractPlottable *> plottables =
+        focussed_widget_p->plottablesToBeUsedAsIntegrationDestination();
+
+      // qDebug() << "The number of plottables to handle:" << plottables.size();
+
+      if(!plottables.size())
+        return;
+
+      if(plottables.size() == 1)
+        requestPlottableDestruction(
+          focussed_widget_p->getPlotWidget(),
+          plottables.first(),
+          focussed_widget_p->getPlotWidget()->getContext());
+      else
+        {
+          // qDebug() << "More than one plottable";
+
+          for(int iter = 0; iter < plottables.size(); ++iter)
+            requestPlottableDestruction(
+              focussed_widget_p->getPlotWidget(),
+              plottables.at(iter),
+              focussed_widget_p->getPlotWidget()->getContext());
+        }
+    }
+}
+
+// This function does not check if there are widgets that are pinned-down so
+// as to gather new trace data. This function creates a brand new plot
+// composite widget.
 QCPGraph *
 MassSpecTracePlotWnd::addTracePlot(
   const pappso::Trace &trace,
@@ -268,9 +335,9 @@ MassSpecTracePlotWnd::integrateToMz(
   //          << "Innermost RT range:" << range_pair.first << "-"
   //          << range_pair.second;
 
-  // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
-  // if(integration_dt)
-  // qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
+  // bool integration_dt = processing_flow.innermostRange("ANY_DT",
+  // range_pair); if(integration_dt) qDebug() << qSetRealNumberPrecision(10)
+  // << "Innermost DT range:"
   //<< "for y axis: " << range_pair.first << "-" << range_pair.second;
 
   // FIXME: END Sanity check that might be removed when the program is
@@ -469,8 +536,8 @@ MassSpecTracePlotWnd::finishedIntegratingToMz(
 
   // qDebug() << "the integrator pointer:" << mass_data_integrator_p;
 
-  // We get back the integrator that was made to work in another thread. Now get
-  // the obtained data and work with them.
+  // We get back the integrator that was made to work in another thread. Now
+  // get the obtained data and work with them.
 
   // Make sure we make a copy of the ProcessingFlow stored in the
   // mass data integrator, because that ProcessingFlow is owned by the
@@ -505,7 +572,6 @@ MassSpecTracePlotWnd::finishedIntegratingToMz(
   // Now that we got all we need and that we have made a safe copy
   // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
-  mass_data_integrator_p = nullptr;
 
   // At this point, we need to get a color for the plot. That color needs to
   // be that of the parent.
@@ -637,7 +703,8 @@ MassSpecTracePlotWnd::handleReceivedData(const QByteArray &byte_array)
   QString title               = cbor_handler.getTitle();
   QByteArray color_byte_array = cbor_handler.getTraceColor();
 
-  // qDebug() << "The data are of type:" << (int)cbor_handler.getMassDataType()
+  // qDebug() << "The data are of type:" <<
+  // (int)cbor_handler.getMassDataType()
   //<< "with title:" << title
   //<< "and trace:" << trace.toString();
 
@@ -711,7 +778,8 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
     ms_run_data_set_sp->craftMzIntegrationParams();
 
   // qDebug().noquote() << "The MzIntegrationParams from the data set:"
-  //                    << ms_run_data_set_mz_integration_params_p->toString();
+  //                    <<
+  //                    ms_run_data_set_mz_integration_params_p->toString();
 
   // Create a temporary ProcessingFlow with nullptr parent because we'll
   // pass it to downstream code as a reference. That will be used to allocate
@@ -722,10 +790,10 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   // We are creating a mass spectrum from a single trace. We arbitrarily set
   // the retention time to 1 min (60 s). We *need* to craft a fake processing
-  // flow step because when the user will use the graph that we will show in the
-  // plot widget to perform an integration, if there is no RT_ANY-related step
-  // in the processing flow, then the integration will invariably yield no data:
-  // no mass spectrum will be found to have a proper retention time.
+  // flow step because when the user will use the graph that we will show in
+  // the plot widget to perform an integration, if there is no RT_ANY-related
+  // step in the processing flow, then the integration will invariably yield
+  // no data: no mass spectrum will be found to have a proper retention time.
 
   ///////////// THE RETENTION TIME (RT) STEP //////////////////
   ProcessingStepSPtr new_step_sp = std::make_shared<ProcessingStep>();
@@ -750,7 +818,8 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   new_step_sp = std::make_shared<ProcessingStep>();
   new_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "SOCKET_MZ");
   new_step_sp->setDestProcessingType(ProcessingType("MZ"));
-  // We now want to create an IntegrationScope that matches the full m/z range.
+  // We now want to create an IntegrationScope that matches the full m/z
+  // range.
   QPointF mz_point(ms_run_data_set_sp->getMsRunDataSetStats().m_minMz, 0);
   width = ms_run_data_set_sp->getMsRunDataSetStats().m_maxMz -
           ms_run_data_set_sp->getMsRunDataSetStats().m_minMz;
@@ -780,8 +849,9 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   temp_processing_flow_p->setDefaultMsFragmentationSpec(fragmentation_spec);
 
   // First thing is create the data plot graph tree, because this is the entry
-  // point to the whole set of data plot graphs : the tree is root into the TIC
-  // chromatogram plot graph because this is where the data exploration starts.
+  // point to the whole set of data plot graphs : the tree is root into the
+  // TIC chromatogram plot graph because this is where the data exploration
+  // starts.
 
   // At this point, we need to get a color for the plot.
   // Set true to ask that the color be selected randomly if no color is
@@ -797,10 +867,10 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   if(!plot_color.isValid())
     plot_color = libXpertMassGui::ColorSelector::getColor(true);
 
-  // Now we should document the mz integration parameters in the processing flow
-  // that is mapped to the graph in such a way that the default mz integration
-  // parameters that were calculated while loading the ms run from file are
-  // available for the very first integration to mz that might occur.
+  // Now we should document the mz integration parameters in the processing
+  // flow that is mapped to the graph in such a way that the default mz
+  // integration parameters that were calculated while loading the ms run from
+  // file are available for the very first integration to mz that might occur.
 
   temp_processing_flow_p->setDefaultMzIntegrationParams(
     *ms_run_data_set_mz_integration_params_p);
