@@ -44,7 +44,6 @@
 
 /////////////////////// Local includes
 #include "BaseTracePlotWnd.hpp"
-#include "MassSpecTracePlotCompositeWidget.hpp"
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToMz.hpp"
 #include <pappsomspp/core/trace/trace.h>
 
@@ -68,6 +67,9 @@ class MassSpecTracePlotWnd: public BaseTracePlotWnd
 
   void createMainMenu();
 
+  void keyPressEvent(QKeyEvent *event);
+  void keyReleaseEvent(QKeyEvent *event);
+
   virtual QCPGraph *
   addTracePlot(const pappso::Trace &trace,
                MsRunDataSetCstSPtr ms_run_data_set_csp,
