@@ -50,7 +50,6 @@
 #include "MsRunDataSetTableViewModel.hpp"
 #include "MsRunDataSetTableViewItem.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -73,7 +72,6 @@ std::map<int, QString> massSpecDataViewColumnsMap = {
 
   {static_cast<int>(MassSpecDataViewColumns::COLUMN_PRECURSOR_Z), "Prec. z"}};
 
-
 MsRunDataSetTableViewModel::MsRunDataSetTableViewModel(
   pappso::MsRunDataSetTreeCstSPtr ms_run_data_set_tree_csp, QObject *parent)
   : QAbstractItemModel(parent), mcsp_msRunDataSetTree(ms_run_data_set_tree_csp)
@@ -81,13 +79,11 @@ MsRunDataSetTableViewModel::MsRunDataSetTableViewModel(
   setupModelData(mcsp_msRunDataSetTree);
 }
 
-
 MsRunDataSetTableViewModel::~MsRunDataSetTableViewModel()
 {
   delete mp_rootItem;
 }
 
-
 int
 MsRunDataSetTableViewModel::columnCount(const QModelIndex &parent) const
 {
@@ -98,7 +94,6 @@ MsRunDataSetTableViewModel::columnCount(const QModelIndex &parent) const
     return mp_rootItem->columnCount();
 }
 
-
 QVariant
 MsRunDataSetTableViewModel::data(const QModelIndex &index, int role) const
 {
@@ -118,7 +113,7 @@ MsRunDataSetTableViewModel::data(const QModelIndex &index, int role) const
       int ms_level_int = ms_level_variant.toInt(&ok);
 
       if(!ok)
-        qFatal("Could not convert QVariant to int.");
+        qFatal() << "Could not convert QVariant to int.";
 
       if(ms_level_int == 1 && view_item_p->childCount() == 0)
         return QVariant();
@@ -157,7 +152,7 @@ MsRunDataSetTableViewModel::data(const QModelIndex &index, int role) const
       int ms_level_int = ms_level_variant.toInt(&ok);
 
       if(!ok)
-        qFatal("Programming error.");
+        qFatal() << "Programming error.";
 
       if(ms_level_int == 1 && view_item_p->childCount() == 0)
         return QVariant();
@@ -188,7 +183,7 @@ MsRunDataSetTableViewModel::data(const QModelIndex &index, int role) const
           int ms_level_int = ms_level_variant.toInt(&ok);
 
           if(!ok)
-            qFatal("Programming error");
+            qFatal() << "Programming error";
 
           switch(ms_level_int)
             {
@@ -229,7 +224,6 @@ MsRunDataSetTableViewModel::data(const QModelIndex &index, int role) const
   return QVariant();
 }
 
-
 Qt::ItemFlags
 MsRunDataSetTableViewModel::flags(const QModelIndex &index) const
 {
@@ -239,7 +233,6 @@ MsRunDataSetTableViewModel::flags(const QModelIndex &index) const
   return QAbstractItemModel::flags(index);
 }
 
-
 QVariant
 MsRunDataSetTableViewModel::headerData(int section,
                                        Qt::Orientation orientation,
@@ -251,7 +244,6 @@ MsRunDataSetTableViewModel::headerData(int section,
   return QVariant();
 }
 
-
 QModelIndex
 MsRunDataSetTableViewModel::index(int row,
                                   int column,
@@ -278,7 +270,6 @@ MsRunDataSetTableViewModel::index(int row,
   return QModelIndex();
 }
 
-
 QModelIndex
 MsRunDataSetTableViewModel::parent(const QModelIndex &index) const
 {
@@ -295,7 +286,6 @@ MsRunDataSetTableViewModel::parent(const QModelIndex &index) const
   return createIndex(parentItem->row(), 0, parentItem);
 }
 
-
 int
 MsRunDataSetTableViewModel::rowCount(const QModelIndex &parent) const
 {
@@ -312,7 +302,6 @@ MsRunDataSetTableViewModel::rowCount(const QModelIndex &parent) const
   return parentItem->childCount();
 }
 
-
 void
 MsRunDataSetTableViewModel::setupModelData(
   pappso::MsRunDataSetTreeCstSPtr ms_run_data_set_tree_csp)
@@ -374,7 +363,7 @@ MsRunDataSetTableViewModel::setupModelData(
               ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
               if(!ok)
                 {
-                  qFatal("Failed to convert QVariant 1/K0 value to double.");
+                  qFatal() << "Failed to convert QVariant 1/K0 value to double.";
                 }
             }
         }
@@ -448,7 +437,7 @@ MsRunDataSetTableViewModel::setupModelData(
 
 #if 0
           if(precursor_index != last_precursor_index)
-            // qFatal("Cannot be that precursor_index != last_precursor_index");
+            // qFatal() << "Cannot be that precursor_index != last_precursor_index";
             qDebug()
               << "Attention, the MSn mass spectrum has no MS(n-1) "
                  "precursor spectrum. This might be a MSn-only mass data file"
