@@ -97,8 +97,8 @@ class MsRunDataSetTableViewWnd: public QMainWindow
 
   void showMzIntegrationParamsDlg();
 
-  void
-  mzIntegrationParamsChanged(const pappso::MzIntegrationParams &mz_integration_params);
+  void mzIntegrationParamsChanged(
+    const pappso::MzIntegrationParams &mz_integration_params);
 
   public slots:
 
