@@ -34,7 +34,6 @@
 
 
 /////////////////////// StdLib includes
-#include <iostream>
 #include <chrono>
 
 /////////////////////// Qt includes
@@ -52,7 +51,7 @@
 
 /////////////////////// Local includes
 #include "MsRunProbeTask.hpp"
-#include "../nongui/MassSpecDataFileLoader.hpp"
+#include "ProgramWindow.hpp"
 
 
 int MsRunProbeTaskMetaTypeId =
@@ -70,7 +69,7 @@ namespace MineXpert
 
 
 MsRunProbeTask::MsRunProbeTask(ProgramWindow *program_window_p)
-  : mp_programWindow(program_window_p)
+  : QObject(program_window_p), mp_programWindow(program_window_p)
 {
 }
 
