@@ -45,14 +45,23 @@
 /////////////////////// pappsomspp includes
 
 
+/////////////////////// libXpertMass includes
+
+
+/////////////////////// libXpertMassGui includes
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
+
+
 /////////////////////// Local includes
 #include "OpenMsRunDataSetsDlg.hpp"
-#include "ui_OpenMsRunDataSetsDlg.h"
 #include "../nongui/MsRunDataSet.hpp"
 #include "Application.hpp"
 #include "BaseTracePlotCompositeWidget.hpp"
 #include "ProgramWindow.hpp"
-#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
+#include "DataPlottableNode.hpp"
+
+#include "ui_OpenMsRunDataSetsDlg.h"
+
 
 namespace MsXpS
 {
@@ -67,20 +76,18 @@ OpenMsRunDataSetsDlg::OpenMsRunDataSetsDlg(QWidget *parent)
     m_ui(new ::Ui::OpenMsRunDataSetsDlg)
 {
   if(parent == Q_NULLPTR)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   if(!initialize())
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 }
 
-
 //! Destruct \c this OpenMsRunDataSetsDlg instance.
 OpenMsRunDataSetsDlg::~OpenMsRunDataSetsDlg()
 {
   writeSettings();
 }
 
-
 //! Handle the close event.
 void
 OpenMsRunDataSetsDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
@@ -89,7 +96,6 @@ OpenMsRunDataSetsDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
   hide();
 }
 
-
 //! Write the settings to as to restore the window geometry later.
 void
 OpenMsRunDataSetsDlg::writeSettings()
@@ -105,7 +111,6 @@ OpenMsRunDataSetsDlg::writeSettings()
   settings.endGroup();
 }
 
-
 //! Read the settings to as to restore the window geometry.
 void
 OpenMsRunDataSetsDlg::readSettings()
@@ -121,7 +126,6 @@ OpenMsRunDataSetsDlg::readSettings()
   settings.endGroup();
 }
 
-
 //! Initialize the window.
 bool
 OpenMsRunDataSetsDlg::initialize()
@@ -137,7 +141,6 @@ OpenMsRunDataSetsDlg::initialize()
   return true;
 }
 
-
 void
 OpenMsRunDataSetsDlg::createMainMenu()
 {
@@ -201,7 +204,6 @@ OpenMsRunDataSetsDlg::createMainMenu()
   mp_mainMenu->addAction(change_plotting_color_p);
 }
 
-
 void
 OpenMsRunDataSetsDlg::show()
 {
@@ -210,7 +212,6 @@ OpenMsRunDataSetsDlg::show()
   QDialog::show();
 }
 
-
 //! Return the number of items in the list widget.
 int
 OpenMsRunDataSetsDlg::itemCount()
@@ -218,7 +219,6 @@ OpenMsRunDataSetsDlg::itemCount()
   return m_ui->openMsRunDataSetsListWidget->count();
 }
 
-
 //! Return the number of items currently selected in the list widget.
 int
 OpenMsRunDataSetsDlg::selectedItemCount()
@@ -226,7 +226,6 @@ OpenMsRunDataSetsDlg::selectedItemCount()
   return m_ui->openMsRunDataSetsListWidget->selectedItems().size();
 }
 
-
 void
 OpenMsRunDataSetsDlg::changePlottingColor()
 {
@@ -300,7 +299,6 @@ OpenMsRunDataSetsDlg::changePlottingColor()
   item_p->setIcon(icon);
 }
 
-
 QColor
 OpenMsRunDataSetsDlg::colorForMsRunDataSet(
   MsRunDataSetCstSPtr &ms_run_data_set_csp) const
@@ -318,7 +316,7 @@ OpenMsRunDataSetsDlg::colorForMsRunDataSet(
 
   if(result == m_msRunDataSetListWidgetItemMap.end())
     {
-      qFatal("Cannot reach this point.");
+      qFatal() << "Cannot reach this point.";
     }
 
   // Release the color that will be made available to other data sets.
@@ -332,7 +330,6 @@ OpenMsRunDataSetsDlg::colorForMsRunDataSet(
   return color;
 }
 
-
 //! Add a new list widget item corresponding to a new TIC chromatogram spectrum.
 /*!
 
@@ -346,7 +343,7 @@ OpenMsRunDataSetsDlg::newOpenMsRunDataSet(
   MsRunDataSetCstSPtr &ms_run_data_set_csp, QColor color)
 {
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug() << "Creating new item in OpenMsRunDataSetsDlg for sample name:"
   //<< ms_run_data_set_csp->getMsRunId()->getSampleName();
@@ -388,7 +385,7 @@ OpenMsRunDataSetsDlg::newOpenMsRunDataSet(
     {
       // One ms run data set was already set, this is a serious error.
 
-      qFatal("Programming error.");
+      qFatal() << "Programming error.";
     }
 
   // Select the lastly added item.
@@ -399,7 +396,6 @@ OpenMsRunDataSetsDlg::newOpenMsRunDataSet(
   //  qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
 }
 
-
 QListWidgetItem *
 OpenMsRunDataSetsDlg::listWidgetItemForMsRunDataSet(
   MsRunDataSetCstSPtr &ms_run_data_set_csp)
@@ -421,7 +417,6 @@ OpenMsRunDataSetsDlg::listWidgetItemForMsRunDataSet(
     return result->second;
 }
 
-
 MsRunDataSetCstSPtr
 OpenMsRunDataSetsDlg::msRunDataSetForListWidgetItem(int index)
 {
@@ -434,7 +429,6 @@ OpenMsRunDataSetsDlg::msRunDataSetForListWidgetItem(int index)
   return msRunDataSetForListWidgetItem(list_widget_item_p);
 }
 
-
 MsRunDataSetCstSPtr
 OpenMsRunDataSetsDlg::msRunDataSetForListWidgetItem(
   QListWidgetItem *list_widget_item_p) const
@@ -470,7 +464,7 @@ OpenMsRunDataSetsDlg::removeMsRunDataSet(
 
   if(list_widget_item_p == nullptr)
     {
-      qFatal("Cannot reach this point.");
+      qFatal() << "Cannot reach this point.";
     }
 
   // Release the color that will be made available to other data sets.
@@ -490,7 +484,6 @@ OpenMsRunDataSetsDlg::removeMsRunDataSet(
   // qDebug() << "Usage count:" << ms_run_data_set_csp.use_count();
 }
 
-
 void
 OpenMsRunDataSetsDlg::closeItems(QList<QListWidgetItem *> widget_items)
 {
@@ -503,7 +496,7 @@ OpenMsRunDataSetsDlg::closeItems(QList<QListWidgetItem *> widget_items)
 
       if(ms_run_data_set_csp == nullptr)
         {
-          qFatal("Cannot reach this point.");
+          qFatal() << "Cannot reach this point.";
         }
 
       // qDebug() << "Going to request the removal of ms run data set:"
@@ -517,7 +510,6 @@ OpenMsRunDataSetsDlg::closeItems(QList<QListWidgetItem *> widget_items)
     }
 }
 
-
 void
 OpenMsRunDataSetsDlg::closeSelected(void)
 {
@@ -529,7 +521,6 @@ OpenMsRunDataSetsDlg::closeSelected(void)
   closeItems(selected_item_list);
 }
 
-
 void
 OpenMsRunDataSetsDlg::closeAllButSelected(void)
 {
@@ -537,7 +528,6 @@ OpenMsRunDataSetsDlg::closeAllButSelected(void)
   closeItems(unselected_item_list);
 }
 
-
 void
 OpenMsRunDataSetsDlg::showMsRunDataSetTableView()
 {
@@ -562,7 +552,7 @@ OpenMsRunDataSetsDlg::showMsRunDataSetTableView()
 
       if(ms_run_data_set_csp == nullptr)
         {
-          qFatal("Cannot reach this point.");
+          qFatal() << "Cannot reach this point.";
         }
 
       std::const_pointer_cast<MsRunDataSet>(ms_run_data_set_csp);
@@ -574,7 +564,6 @@ OpenMsRunDataSetsDlg::showMsRunDataSetTableView()
     }
 }
 
-
 QList<QListWidgetItem *>
 OpenMsRunDataSetsDlg::unselectedItems()
 {
@@ -594,14 +583,12 @@ OpenMsRunDataSetsDlg::unselectedItems()
   return unselected_items;
 }
 
-
 std::size_t
 OpenMsRunDataSetsDlg::msRunDataSetCount() const
 {
   return m_ui->openMsRunDataSetsListWidget->count();
 }
 
-
 void
 OpenMsRunDataSetsDlg::selectFirstMsRunDataSet()
 {
@@ -612,7 +599,6 @@ OpenMsRunDataSetsDlg::selectFirstMsRunDataSet()
   m_ui->openMsRunDataSetsListWidget->setCurrentRow(0);
 }
 
-
 bool
 OpenMsRunDataSetsDlg::singleSelectedOrUniqueMsRunDataSet(
   MsRunDataSetCstSPtr &ms_run_data_set_csp, QColor &color) const
@@ -660,7 +646,6 @@ OpenMsRunDataSetsDlg::singleSelectedOrUniqueMsRunDataSet(
   return true;
 }
 
-
 std::vector<MsRunDataSetCstSPtr>
 OpenMsRunDataSetsDlg::allMsRunDataSets() const
 {
@@ -679,7 +664,6 @@ OpenMsRunDataSetsDlg::allMsRunDataSets() const
   return vector_of_ms_run_data_set_csp;
 }
 
-
 std::vector<MsRunDataSetCstSPtr>
 OpenMsRunDataSetsDlg::allSelectedOrUniqueMsRunDataSets() const
 {
@@ -704,7 +688,6 @@ OpenMsRunDataSetsDlg::allSelectedOrUniqueMsRunDataSets() const
   return vector_of_ms_run_data_set_csp;
 }
 
-
 bool
 OpenMsRunDataSetsDlg::msRunDataSetFromSampleName(
   const QString &sample_name,
@@ -733,13 +716,12 @@ OpenMsRunDataSetsDlg::msRunDataSetFromSampleName(
   return true;
 }
 
-
 bool
 OpenMsRunDataSetsDlg::colorFromMsRunDataSet(
   MsRunDataSetCstSPtr ms_run_data_set_csp, QColor &color)
 {
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   color = colorForMsRunDataSet(ms_run_data_set_csp);
 
