@@ -671,13 +671,19 @@ ProgramWindow::setupWindow()
   // Because we already have initialized the libXpertMassCore library,
   // we can load all the shortcuts.
   mp_actionManager->loadActionData();
-  qDebug() << "Loaded" << mp_actionManager->actionCount() << "actions.";
+
+  // qDebug() << "Loaded" << mp_actionManager->actionCount() << "actions.";
 
   // Now create the menus and actions taking profit of the potentially
   // configured shortcuts loaded above.
+  // qDebug() << "Start creating menus and actions";
   createMenusAndActions();
+  // qDebug() << "Stop creating menus and actions";
 
+  // qDebug() << "Start initializing all windows.";
   initializeAllWindows();
+  // qDebug() << "Stop initializing all windows.";
+
   displayArticleCitationHelpPage();
   initializeScripting();
 }
@@ -965,7 +971,7 @@ void
 ProgramWindow::updateDiscoveriesPreferences(
   const DiscoveriesPreferences &discovery_preferences)
 {
-  qDebug() << "Updating DiscoveriesPreferences";
+  // qDebug() << "Updating DiscoveriesPreferences";
 
   // This function is called by the Discoveries page of the
   // ApplicationPreferences window.
@@ -2564,9 +2570,16 @@ ProgramWindow::showApplicationPreferencesWnd()
   mp_applicationPreferencesWnd->show();
 }
 
+const ApplicationPreferencesWnd *
+ProgramWindow::getApplicationPreferencesWnd()
+{
+  return mp_applicationPreferencesWnd;
+}
+
 void
 ProgramWindow::saveWorkspace()
 {
+  writeSettings();
   mp_openMsRunDataSetsDlg->writeSettings();
   mp_taskMonitorWnd->writeSettings();
   mp_consoleWnd->writeSettings();
@@ -2578,6 +2591,8 @@ ProgramWindow::saveWorkspace()
   mp_ticXicChromDriftSpecColorMapWnd->writeSettings();
   mp_driftSpecMassSpecColorMapWnd->writeSettings();
 
+  mp_applicationPreferencesWnd->writeSettings();
+
   mp_xicExtractionWnd->writeSettings();
 }
 
