@@ -63,13 +63,12 @@ TaskMonitorCompositeWidget::TaskMonitorCompositeWidget(QWidget *parent_p)
   // By essence, the parent will be the task monitor window.
 
   if(parent_p == nullptr)
-    qFatal("parent cannot be nullptr");
+    qFatal() << "parent cannot be nullptr";
 
 
   setupWindow();
 }
 
-
 TaskMonitorCompositeWidget::TaskMonitorCompositeWidget(QWidget *parent_p,
                                                        const QColor &color)
   : QWidget(parent_p),
@@ -79,18 +78,16 @@ TaskMonitorCompositeWidget::TaskMonitorCompositeWidget(QWidget *parent_p,
   // By essence, the parent will be the task monitor window.
 
   if(parent_p == nullptr)
-    qFatal("parent cannot be nullptr");
+    qFatal() << "parent cannot be nullptr";
 
   setupWindow();
 }
 
-
 TaskMonitorCompositeWidget::~TaskMonitorCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 TaskMonitorCompositeWidget::setupWindow()
 {
@@ -102,7 +99,6 @@ TaskMonitorCompositeWidget::setupWindow()
           &TaskMonitorCompositeWidget::cancelTask);
 }
 
-
 void
 TaskMonitorCompositeWidget::setColor(const QColor &color)
 {
@@ -119,14 +115,12 @@ TaskMonitorCompositeWidget::setColor(const QColor &color)
   m_ui->msRunIdLabel->setText("ms run id");
 }
 
-
 const QColor &
 TaskMonitorCompositeWidget::getColor() const
 {
   return m_color;
 }
 
-
 void
 TaskMonitorCompositeWidget::makeMassDataIntegratorConnections(
   MassDataIntegrator *mass_data_integrator_p)
@@ -216,7 +210,6 @@ TaskMonitorCompositeWidget::makeMassDataIntegratorConnections(
           &TaskMonitorCompositeWidget::unlock);
 }
 
-
 void
 TaskMonitorCompositeWidget::makeMassDataIntegratorConnections(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p)
@@ -317,7 +310,6 @@ TaskMonitorCompositeWidget::makeMassDataIntegratorConnections(
           &TaskMonitorCompositeWidget::unlock);
 }
 
-
 void
 TaskMonitorCompositeWidget::makeMassSpecDataFileLoaderConnections(
   MassSpecDataFileLoader *mass_spec_data_file_loader_p)
@@ -383,7 +375,6 @@ TaskMonitorCompositeWidget::makeMassSpecDataFileLoaderConnections(
           &TaskMonitorCompositeWidget::unlock);
 }
 
-
 void
 TaskMonitorCompositeWidget::makeMsRunProberConnections(
   MsRunProber *ms_run_prober_p)
@@ -442,21 +433,18 @@ TaskMonitorCompositeWidget::makeMsRunProberConnections(
           &TaskMonitorCompositeWidget::unlock);
 }
 
-
 void
 TaskMonitorCompositeWidget::setTimeLag(double time_lag)
 {
   m_timeLag = time_lag;
 }
 
-
 double
 TaskMonitorCompositeWidget::getTimeLag() const
 {
   return m_timeLag;
 }
 
-
 bool
 TaskMonitorCompositeWidget::shouldUpdate()
 
@@ -483,7 +471,6 @@ TaskMonitorCompositeWidget::shouldUpdate()
   return result;
 }
 
-
 /****************************** Slots *****************************/
 /****************************** Slots *****************************/
 
@@ -504,7 +491,6 @@ TaskMonitorCompositeWidget::cancelTask()
   // doulbe free of same pointer and crash.
 }
 
-
 void
 TaskMonitorCompositeWidget::taskFinished()
 {
@@ -517,10 +503,11 @@ TaskMonitorCompositeWidget::taskFinished()
 
   // Program the auto destruction of this.
 
-  QTimer::singleShot(1500, [this]() { this->deleteLater(); });
+  QTimer::singleShot(1500, [this]() {
+    this->deleteLater();
+  });
 }
 
-
 void
 TaskMonitorCompositeWidget::setupProgressBar(int min_value, int max_value)
 {
@@ -532,7 +519,6 @@ TaskMonitorCompositeWidget::setupProgressBar(int min_value, int max_value)
     }
 }
 
-
 void
 TaskMonitorCompositeWidget::setProgressBarMinValue(int value)
 {
@@ -543,7 +529,6 @@ TaskMonitorCompositeWidget::setProgressBarMinValue(int value)
     }
 }
 
-
 void
 TaskMonitorCompositeWidget::setProgressBarMaxValue(int value)
 {
@@ -555,7 +540,6 @@ TaskMonitorCompositeWidget::setProgressBarMaxValue(int value)
     }
 }
 
-
 void
 TaskMonitorCompositeWidget::incrementProgressBarMaxValue(int increment)
 {
@@ -566,7 +550,6 @@ TaskMonitorCompositeWidget::incrementProgressBarMaxValue(int increment)
   m_ui->progressBar->setMaximum(new_value);
 }
 
-
 void
 TaskMonitorCompositeWidget::setProgressBarCurrentValue(int value)
 {
@@ -577,7 +560,6 @@ TaskMonitorCompositeWidget::setProgressBarCurrentValue(int value)
     }
 }
 
-
 void
 TaskMonitorCompositeWidget::setMsRunIdText(QString text)
 {
@@ -585,14 +567,12 @@ TaskMonitorCompositeWidget::setMsRunIdText(QString text)
     m_ui->msRunIdLabel->setText(text);
 }
 
-
 QString
 TaskMonitorCompositeWidget::getMsRunIdText()
 {
   return m_ui->msRunIdLabel->text();
 }
 
-
 void
 TaskMonitorCompositeWidget::setTaskDescriptionText(QString text)
 {
@@ -600,7 +580,6 @@ TaskMonitorCompositeWidget::setTaskDescriptionText(QString text)
     m_ui->taskDescriptionLineEdit->setText(text);
 }
 
-
 void
 TaskMonitorCompositeWidget::clearTaskDescriptionText()
 {
@@ -608,14 +587,12 @@ TaskMonitorCompositeWidget::clearTaskDescriptionText()
     m_ui->taskDescriptionLineEdit->setText("");
 }
 
-
 QString
 TaskMonitorCompositeWidget::getTaskDescriptionText()
 {
   return m_ui->taskDescriptionLineEdit->text();
 }
 
-
 void
 TaskMonitorCompositeWidget::setStatusText(QString text)
 {
@@ -626,7 +603,6 @@ TaskMonitorCompositeWidget::setStatusText(QString text)
     m_ui->statusLineEdit->setText(text);
 }
 
-
 void
 TaskMonitorCompositeWidget::appendStatusText(QString text)
 {
@@ -634,14 +610,12 @@ TaskMonitorCompositeWidget::appendStatusText(QString text)
     m_ui->statusLineEdit->setText(m_ui->statusLineEdit->text() + text);
 }
 
-
 QString
 TaskMonitorCompositeWidget::getStatusText()
 {
   return m_ui->statusLineEdit->text();
 }
 
-
 void
 TaskMonitorCompositeWidget::clearStatusText()
 {
@@ -649,7 +623,6 @@ TaskMonitorCompositeWidget::clearStatusText()
     m_ui->statusLineEdit->setText("");
 }
 
-
 void
 TaskMonitorCompositeWidget::setStatusTextAndCurrentValue(QString text,
                                                          int value)
@@ -662,7 +635,6 @@ TaskMonitorCompositeWidget::setStatusTextAndCurrentValue(QString text,
     }
 }
 
-
 void
 TaskMonitorCompositeWidget::incrementProgressBarCurrentValue(int increment)
 {
@@ -673,7 +645,6 @@ TaskMonitorCompositeWidget::incrementProgressBarCurrentValue(int increment)
     }
 }
 
-
 void
 TaskMonitorCompositeWidget::incrementProgressBarCurrentValueAndSetStatusText(
   int increment, QString text)
@@ -703,28 +674,24 @@ TaskMonitorCompositeWidget::incrementProgressBarCurrentValueAndSetStatusText(
     }
 }
 
-
 void
 TaskMonitorCompositeWidget::lock()
 {
   m_isLocked = true;
 }
 
-
 void
 TaskMonitorCompositeWidget::unlock()
 {
   m_isLocked = false;
 }
 
-
 bool
 TaskMonitorCompositeWidget::isLocked() const
 {
   return m_isLocked;
 }
 
-
 QString
 TaskMonitorCompositeWidget::craftStringIfFormattedText(
   const QString &text) const
