@@ -52,7 +52,6 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -68,16 +67,15 @@ TicXicChromDriftSpecColorMapWnd::TicXicChromDriftSpecColorMapWnd(
   : BaseColorMapPlotWnd(parent, title, settingsTitle, description)
 {
   // qDebug() ;
+  setWindowIcon(qApp->windowIcon());
 }
 
-
 //! Destruct \c this TicXicChromDriftSpecColorMapWnd instance.
 TicXicChromDriftSpecColorMapWnd::~TicXicChromDriftSpecColorMapWnd()
 {
   // qDebug() ;
 }
 
-
 QCPColorMap *
 TicXicChromDriftSpecColorMapWnd::addColorMapPlot(
   std::shared_ptr<std::map<double, pappso::MapTrace>> &rt_maptrace_map,
@@ -127,7 +125,6 @@ TicXicChromDriftSpecColorMapWnd::addColorMapPlot(
                                            parent_plottable_p);
 }
 
-
 void
 TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   QCPAbstractPlottable *parent_plottable_p,
@@ -143,7 +140,7 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
@@ -153,7 +150,7 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
 
   if(!integration_rt)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
   //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
@@ -162,7 +159,8 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
   //
   // if(integration_dt)
   //   qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-  //            << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  //            << "for y axis: " << range_pair.first << "-" <<
+  //            range_pair.second;
 
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
@@ -176,7 +174,8 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
   // qDebug()
-  //   << "The number of selected mass spectra on the basis of rough RT/DT values:"
+  //   << "The number of selected mass spectra on the basis of rough RT/DT
+  //   values:"
   //   << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
@@ -327,7 +326,6 @@ TicXicChromDriftSpecColorMapWnd::integrateToDtRt(
              &MassDataIntegratorTask::integrateToDtRt);
 }
 
-
 void
 TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
