@@ -52,7 +52,6 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -67,15 +66,14 @@ TicXicChromMassSpecColorMapWnd::TicXicChromMassSpecColorMapWnd(
   const QString &description)
   : BaseColorMapPlotWnd(parent, title, settingsTitle, description)
 {
+  setWindowIcon(qApp->windowIcon());
 }
 
-
 //! Destruct \c this TicXicChromMassSpecColorMapWnd instance.
 TicXicChromMassSpecColorMapWnd::~TicXicChromMassSpecColorMapWnd()
 {
 }
 
-
 QCPColorMap *
 TicXicChromMassSpecColorMapWnd::addColorMapPlot(
   std::shared_ptr<std::map<double, pappso::MapTrace>> &double_map_trace_map_sp,
@@ -103,7 +101,6 @@ TicXicChromMassSpecColorMapWnd::addColorMapPlot(
                                            parent_plottable_p);
 }
 
-
 void
 TicXicChromMassSpecColorMapWnd::integrateToMzRt(
   QCPAbstractPlottable *parent_plottable_p,
@@ -119,7 +116,7 @@ TicXicChromMassSpecColorMapWnd::integrateToMzRt(
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
@@ -128,7 +125,7 @@ TicXicChromMassSpecColorMapWnd::integrateToMzRt(
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
 
   if(!integration_rt)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
   //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
@@ -137,7 +134,8 @@ TicXicChromMassSpecColorMapWnd::integrateToMzRt(
   //
   // if(integration_dt)
   //   qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-  //            << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  //            << "for y axis: " << range_pair.first << "-" <<
+  //            range_pair.second;
 
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
@@ -302,7 +300,6 @@ TicXicChromMassSpecColorMapWnd::integrateToMzRt(
              &MassDataIntegratorTask::integrateToDtRtMz);
 }
 
-
 void
 TicXicChromMassSpecColorMapWnd::finishedIntegratingToRtMz(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
