@@ -75,9 +75,10 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
 {
   // qDebug();
 
-  static_assert(std::is_base_of_v<QWidget, TicXicChromTracePlotCompositeWidget>);
+  static_assert(
+    std::is_base_of_v<QWidget, TicXicChromTracePlotCompositeWidget>);
 
-  dynamic_cast<QWidget*>(this)->setWindowIcon(qApp->windowIcon());
+  dynamic_cast<QWidget *>(this)->setWindowIcon(qApp->windowIcon());
 
   /************  The QCustomPlot widget *************/
   /************  The QCustomPlot widget *************/
@@ -168,7 +169,7 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
 void
 TicXicChromTracePlotCompositeWidget::createMainMenu()
 {
-  qDebug() << "Completing the main menu:" << mp_mainMenu;
+  // qDebug() << "Completing the main menu:" << mp_mainMenu;
 
   // Update the menu tooltip.
   m_ui->mainMenuPushButton->setToolTip(
@@ -281,7 +282,7 @@ void
 TicXicChromTracePlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
 {
-  qDebug().noquote() << "context:" << context.toString();
+  // qDebug().noquote() << "context:" << context.toString();
 
   // Make a local copy of the context because we may need to modify it.
   pappso::BasePlotContext local_context;
@@ -293,9 +294,10 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
   if(local_context.msp_integrationScope->is2D())
     {
-      qInfo() << "Odd situation where the selection polygon is two-dimensional "
-                 "and the trace plot selection is mono-dimensional. Converting "
-                 "it to a 1D selection polygon.";
+      // qDebug()
+      //   << "Odd situation where the selection polygon is two-dimensional "
+      //      "and the trace plot selection is mono-dimensional. Converting "
+      //      "it to a 1D selection polygon.";
 
       double width;
       if(!local_context.msp_integrationScope->getWidth(width))
@@ -324,10 +326,10 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   local_context.msp_integrationScope->range(
     pappso::Enums::Axis::x, range_start, range_end);
 
-  qDebug().noquote() << "Local copy of context:" << local_context.toString();
+  // qDebug().noquote() << "Local copy of context:" << local_context.toString();
 
-  qDebug() << "X axis range extracted from integration scope:" << range_start
-           << "-" << range_end;
+  // qDebug() << "X axis range extracted from integration scope:" << range_start
+  //          << "-" << range_end;
 
   // Having negative retention times does not make any sense.
   if(range_start < 0 && range_end < 0)
@@ -575,18 +577,18 @@ QString
 TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
   const pappso::BasePlotContext &context)
 {
-    Q_UNUSED(context)
+  Q_UNUSED(context)
 
-    // qDebug().noquote() << "With context:" << context.toString();
-    // qDebug().noquote()
-    // << "We get from the base class stanza work the following text:"
-    // << m_analysisStanza;
+  // qDebug().noquote() << "With context:" << context.toString();
+  // qDebug().noquote()
+  // << "We get from the base class stanza work the following text:"
+  // << m_analysisStanza;
 
-    // Since this class has no specialized data, apart those already handled
-    // in the base class function, all we need to do is return the stanza that
-    // has already been crafted by the base class.
+  // Since this class has no specialized data, apart those already handled
+  // in the base class function, all we need to do is return the stanza that
+  // has already been crafted by the base class.
 
-    return m_analysisStanza;
+  return m_analysisStanza;
 }
 
 } // namespace MineXpert
