@@ -1,4 +1,3 @@
-
 /* BEGIN software license
  *
  * msXpertSuite - mass spectrometry software suite
@@ -61,7 +60,7 @@ namespace MineXpert
 // XIC-specific functions. In particular the integrationRequested() function
 // needs to be specialized because that function would not work if the data were
 // of a MassSpectrum or a DriftSpectrum type.
-class TicXicChromTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
+class TicXicChromTracePlotCompositeWidget: public BaseTracePlotCompositeWidget
 {
   Q_OBJECT
 
@@ -81,8 +80,7 @@ class TicXicChromTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
   virtual void
   plotWidgetMousePressEvent(const pappso::BasePlotContext &context);
 
-  virtual void
-  plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context);
+  virtual void plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context);
 
   virtual void moveMouseCursorToNextGraphPoint(
     const pappso::BasePlotContext &context) override;
@@ -91,12 +89,14 @@ class TicXicChromTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 
   QString craftAnalysisStanza(const pappso::BasePlotContext &context);
 
-  signals:
+  protected:
+   void createMainMenu() ;
 
   private:
   void setupWidget() override;
 };
 
+static_assert(std::is_base_of_v<QWidget, TicXicChromTracePlotCompositeWidget>);
 
 } // namespace MineXpert
 
