@@ -240,9 +240,9 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   ProcessingFlow *temp_processing_flow_p =
     mass_data_integrator_p->getProcessingFlow()->clone(nullptr);
 
-  qDebug()
-    << "After integrating to the first TIC chromatogram, processing flow:"
-    << temp_processing_flow_p->toString(0, "  ");
+  // qDebug()
+  //   << "After integrating to the first TIC chromatogram, processing flow:"
+  //   << temp_processing_flow_p->toString(0, "  ");
 
   // Note that we are in special situation: we are now handling a TIC
   // chromatogram that was computed as a very first integration right after
@@ -261,7 +261,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   // first step in the processing flow right after opening a data file.
 
   if(most_recent_step_sp != nullptr)
-    qInfo() << "Odd situation that a processing step existed before now.";
+    qDebug() << "Odd situation that a processing step existed before now.";
 
   // if(most_recent_step_sp->destMatches("FILE_RT"))
   //   qFatal(
@@ -320,9 +320,11 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
     temp_processing_flow_p->getDefaultMzIntegrationParams();
   // We have set them above, they must be found!
   Q_ASSERT(mz_integration_params_p);
-  qDebug().noquote()
-    << "The mz integration params set to the processing flow:\n"
-    << mz_integration_params_p->toString(0, "  ");
+
+  // qDebug().noquote()
+  //   << "The mz integration params set to the processing flow:\n"
+  //   << mz_integration_params_p->toString(0, "  ");
+
 #endif
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
