@@ -69,7 +69,7 @@ XicExtractionWnd::XicExtractionWnd(ProgramWindow *program_window_p,
   // qDebug();
 
   if(program_window_p == nullptr)
-    qFatal("Pointer cannot be nullptr.");
+    qFatal() << "Pointer cannot be nullptr.";
 
   m_ui->setupUi(this);
 
@@ -84,6 +84,8 @@ XicExtractionWnd::~XicExtractionWnd()
 void
 XicExtractionWnd::initialize()
 {
+  setWindowIcon(qApp->windowIcon());
+
   // The precision widget required to specify the precursor m/z values
   // search tolerance.
   mp_precisionWidget = new pappso::PrecisionWidget(this);
@@ -228,7 +230,8 @@ XicExtractionWnd::runPushButtonClicked()
           ProcessingStepSPtr processing_step_sp =
             std::make_shared<ProcessingStep>();
 
-          processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "RT");
+          processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x,
+                                                   "RT");
           processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::y,
                                                    "DATA_XIC_MZ");
 
