@@ -38,7 +38,7 @@
 #include <ctime>
 
 /////////////////////// OpenMP include
-#include <omp.h>
+// #include <omp.h>
 
 /////////////////////// Qt includes
 #include <QDebug>
