@@ -211,6 +211,46 @@ myMessageOutputFormat(QtMsgType type,
   fflush(stderr); // Ensure it actually appears
 }
 
+namespace MsXpS
+{
+namespace MineXpert
+{
+
+
+#if 0
+
+// Magic bullet for global keyboard key tracking.
+class GlobalKeyTracker: public QObject
+{
+  protected:
+  bool
+  eventFilter(QObject *obj, QEvent *event) override
+  {
+    if(event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease)
+      {
+        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        QKeySequence keySequence(keyEvent->key() | keyEvent->modifiers());
+
+        // Get detailed key information
+        qDebug() << "=== KEY EVENT ==="
+                 << "\nWidget:" << obj->metaObject()->className()
+                 << "\nObject name:" << obj->objectName()
+                 << "\nKey:" << keyEvent->key() << "\nText:" << keyEvent->text()
+                 << "\nKey sequence:" << keySequence.toString()
+                 << "\nNative scan code:" << keyEvent->nativeScanCode()
+                 << "\nNative virtual key:" << keyEvent->nativeVirtualKey()
+                 << "\nModifiers:" << keyEvent->modifiers() << "\nType:"
+                 << (event->type() == QEvent::KeyPress ? "Press" : "Release");
+      }
+    return false; // Don't block the event
+  }
+};
+
+#endif
+
+} // namespace MineXpert
+} // namespace MsXpS
+
 int
 main(int argc, char **argv)
 {
@@ -229,6 +269,33 @@ main(int argc, char **argv)
   application.setApplicationName(project_name);
   application.setApplicationDisplayName(project_name);
 
+#if 0
+  // This is magic debugging stuff to see how a keyboard stroke is gotten
+  // from the application (what widget, what code...)
+  MsXpS::MineXpert::GlobalKeyTracker *key_tracker_p =
+    new MsXpS::MineXpert::GlobalKeyTracker();
+  application.installEventFilter(key_tracker_p);
+#endif
+
+#if 0
+  // Useful debug code to highlight the widget that gets focus.
+  QObject::connect(
+    qApp,
+    &QApplication::focusChanged,
+    &application,
+    [](QWidget *old, QWidget *now) {
+      if(old)
+        old->setStyleSheet(""); // Remove highlight from old widget
+      if(now)
+        {
+          qDebug() << "Focus changed to:" << now->metaObject()->className();
+          now->setStyleSheet(
+            "border: 2px solid red;"); // Highlight focused widget
+        }
+    });
+#endif
+
+
   QCommandLineParser parser;
 
   parser.setApplicationDescription(
@@ -316,8 +383,9 @@ main(int argc, char **argv)
   // windows allocated by ProgramWindow during its construction time
   // need to be able to call application.getProgramWindow().
   application.setProgramWindow(main_window_p);
-  qDebug() << "Set the pointer to ProgramWindow in Application to "
-           << application.getProgramWindow();
+
+  // qDebug() << "Set the pointer to ProgramWindow in Application to "
+  //          << application.getProgramWindow();
 
   main_window_p->setupWindow();
   dynamic_cast<QWidget *>(main_window_p)->show();
