@@ -33,7 +33,7 @@
 
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 QString gpl(
@@ -775,6 +775,6 @@ QString gplLegalDisclaimerLiabilitySections(
   "SUCH DAMAGES.\n"
   "\n");
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
