@@ -72,6 +72,7 @@ BaseMsRunDataSetTreeNodeVisitor::BaseMsRunDataSetTreeNodeVisitor(
 
 BaseMsRunDataSetTreeNodeVisitor::~BaseMsRunDataSetTreeNodeVisitor()
 {
+  // qDebug();
 }
 
 void
@@ -117,9 +118,9 @@ BaseMsRunDataSetTreeNodeVisitor::checkQualifiedMassSpectrum(
     node.getQualifiedMassSpectrum();
 
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
   if(qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   if(qualified_mass_spectrum_csp->getMassSpectrumSPtr() == nullptr)
     {
@@ -140,7 +141,7 @@ BaseMsRunDataSetTreeNodeVisitor::checkQualifiedMassSpectrum(
     }
 
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("QualifiedMassSpectrum cannot be nullptr.");
+    qFatal() << "QualifiedMassSpectrum cannot be nullptr.";
 
   // qDebug() << "Retention time is:" <<
   // qualified_mass_spectrum_csp->getRtInMinutes();
@@ -149,7 +150,7 @@ BaseMsRunDataSetTreeNodeVisitor::checkQualifiedMassSpectrum(
   // Leptocheline_MS3_DDA_IT_1.mzml test file.
 
   // if(!qualified_mass_spectrum_csp->size())
-  // qFatal("The qualified mass spectrum is empty (size is 0).");
+  // qFatal() << "The qualified mass spectrum is empty (size is 0).";
 
   return qualified_mass_spectrum_csp;
 }
@@ -160,9 +161,9 @@ BaseMsRunDataSetTreeNodeVisitor::checkMsLevel(
 {
 
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
   if(qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   // qDebug().noquote() << "Checking MS level for qualified mass spectrum:"
   //<< qualified_mass_spectrum_csp->toString();
@@ -345,7 +346,7 @@ BaseMsRunDataSetTreeNodeVisitor::checkDtRange(
           ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
           if(!ok)
             {
-              qFatal("Failed to convert QVariant 1/K0 value to double.");
+              qFatal() << "Failed to convert QVariant 1/K0 value to double.";
             }
         }
     }
