@@ -36,7 +36,7 @@
 #include <iomanip>
 
 /////////////////////// OpenMP include
-#include <omp.h>
+// #include <omp.h>
 
 /////////////////////// Qt includes
 #include <QObject>
