@@ -38,10 +38,11 @@
 
 
 /////////////////////// Qt includes
+#include <QObject>
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/trace/maptrace.h>
+#include <pappsomspp/core/trace/maptrace.h>
 
 
 /////////////////////// Local includes
@@ -49,35 +50,39 @@
 #include "MsRunDataSet.hpp"
 #include "ProcessingFlow.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class MassDataIntegrator;
 
 typedef std::shared_ptr<MassDataIntegrator> MassDataIntegratorSPtr;
 
-class MassDataIntegrator : public QObject
+class MassDataIntegrator: public QObject
 {
   Q_OBJECT
 
   public:
-  MassDataIntegrator();
+  MassDataIntegrator(QObject *parent = nullptr);
 
-  MassDataIntegrator(MsRunDataSetCstSPtr ms_run_data_set_csp);
   MassDataIntegrator(MsRunDataSetCstSPtr ms_run_data_set_csp,
-                     const ProcessingFlow &processing_flow);
-
-  MassDataIntegrator(const MassDataIntegrator &other);
+                     QObject *parent = nullptr);
+  MassDataIntegrator(MsRunDataSetCstSPtr ms_run_data_set_csp,
+                     const ProcessingFlow &processing_flow,
+                     QObject *parent = nullptr);
 
   virtual ~MassDataIntegrator();
 
+  MassDataIntegrator *clone(QObject *parent = nullptr) const;
+
   void setMsRunDataSet(MsRunDataSetCstSPtr ms_run_data_set_csp);
   MsRunDataSetCstSPtr getMsRunDataSet() const;
 
-  const ProcessingFlow &getProcessingFlow() const;
+  void setProcessingFlow(const ProcessingFlow &processing_flow);
+  const ProcessingFlow &getProcessingFlowCstRef() const;
+  ProcessingFlow &getProcessingFlowRef();
+  ProcessingFlow *getProcessingFlow();
 
   const pappso::MapTrace &getMapTrace() const;
   const std::shared_ptr<std::map<double, pappso::MapTrace>>
@@ -118,7 +123,7 @@ class MassDataIntegrator : public QObject
   protected:
   MsRunDataSetCstSPtr mcsp_msRunDataSet = nullptr;
 
-  ProcessingFlow m_processingFlow;
+  ProcessingFlow *mp_processingFlow;
 
   // These are the data structure used to store the result of the computation.
 
@@ -152,12 +157,6 @@ class MassDataIntegrator : public QObject
                                              int nodes_per_thread);
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
-
-Q_DECLARE_METATYPE(MsXpS::minexpert::MassDataIntegrator)
-extern int massDataIntegratorMetaTypeId;
-
-Q_DECLARE_METATYPE(MsXpS::minexpert::MassDataIntegratorSPtr)
-extern int massDataIntegratorSPtrMetaTypeId;
