@@ -234,7 +234,7 @@ MsRunDataSet::craftMzIntegrationParams() const
     m_msRunDataSetStats.m_maxMz,
     pappso::MzIntegrationParams::BinningType::ARBITRARY,
     pappso::PrecisionFactory::getResInstance(40000),
-     1 /*binSizeDivisor*/,
+    1 /*binSizeDivisor*/,
     -1 /*decimalPlaces*/,
     true /*removeZeroValDataPoints*/);
 }
@@ -265,7 +265,7 @@ MsRunDataSet::mapMassSpectrum(
 
   if(qualified_mass_spectrum_csp == nullptr ||
      qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr.");
+    qFatal() << "Cannot be nullptr.";
 
   pappso::MsRunDataSetTreeNode *new_node_p =
     msp_msRunDataSetTree->addMassSpectrum(qualified_mass_spectrum_csp);
@@ -276,7 +276,7 @@ MsRunDataSet::mapMassSpectrum(
   // We want to standardize retention time to be in min
   double rt = qualified_mass_spectrum_csp->getRtInMinutes();
   if(rt == -1)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // A single rt value in the map is associated to a list of ms run
   // data set tree nodes.
@@ -329,7 +329,7 @@ MsRunDataSet::mapMassSpectrum(
           ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
           if(!ok)
             {
-              qFatal("Failed to convert QVariant 1/K0 value to double.");
+              qFatal() << "Failed to convert QVariant 1/K0 value to double.";
             }
         }
       // else
