@@ -187,7 +187,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       range_end - range_start,
       pappso::Enums::DataKind::rt);
   step_sp->setIntegrationScope(integration_scope_csp);
-  qDebug() << "Step is:" << step_sp->toString();
+  // qDebug() << "Step is:" << step_sp->toString();
 
   // qDebug() << "Created 1D selection polygon:"
   //<< step_p->getSelectionPolygon().toString();
@@ -262,7 +262,8 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       // one visitor for initial TIC chrom calculation and one for the initial
       // ms run data set statistics.
 
-      // qDebug() << "Now heap-allocating TicChromTreeNodeCombinerVisitor, thread"
+      // qDebug() << "Now heap-allocating TicChromTreeNodeCombinerVisitor,
+      // thread"
       //          << QThread::currentThreadId();
 
       // Start with first visitor that will compute the TIC chromatogram
@@ -275,7 +276,8 @@ MsRunDataSetTreeMassDataIntegratorToRt::
            thanks to this parentship.*/
           multi_visitor_p);
 
-      // qDebug() << "Done heap-allocating TicChromTreeNodeCombinerVisitor, thread"
+      // qDebug() << "Done heap-allocating TicChromTreeNodeCombinerVisitor,
+      // thread"
       //          << QThread::currentThreadId();
 
       multi_visitor_p->addVisitor(tic_visitor_p);
@@ -516,7 +518,8 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   emit logTextToConsoleSignal(chrono_string);
   // qDebug().noquote() << chrono_string;
 
-  // Free all the visitors (we can do this because we have passed nullptr as the parent):
+  // Free all the visitors (we can do this because we have passed nullptr as the
+  // parent):
   foreach(BaseMsRunDataSetTreeNodeVisitor *visitor_p, visitors)
     delete visitor_p;
 
