@@ -41,7 +41,7 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/trace/maptrace.h>
+#include <pappsomspp/core/trace/maptrace.h>
 
 
 /////////////////////// Local includes
@@ -49,37 +49,29 @@
 #include "ProcessingFlow.hpp"
 #include "MassDataIntegrator.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-class MsRunDataSetTreeMassDataIntegratorToRt;
-
-typedef std::shared_ptr<MsRunDataSetTreeMassDataIntegratorToRt>
-  MsRunDataSetTreeMassDataIntegratorToRtSPtr;
-
-class MsRunDataSetTreeMassDataIntegratorToRt : public MassDataIntegrator
+class MsRunDataSetTreeMassDataIntegratorToRt: public MassDataIntegrator
 {
   Q_OBJECT
 
   public:
-  MsRunDataSetTreeMassDataIntegratorToRt();
+  MsRunDataSetTreeMassDataIntegratorToRt(QObject *parent = nullptr);
 
   MsRunDataSetTreeMassDataIntegratorToRt(
-    MsRunDataSetCstSPtr ms_run_data_set_csp);
+    MsRunDataSetCstSPtr ms_run_data_set_csp, QObject *parent = nullptr);
 
   MsRunDataSetTreeMassDataIntegratorToRt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
-    const ProcessingFlow &processing_flow);
-
-  MsRunDataSetTreeMassDataIntegratorToRt(
-    const MsRunDataSetTreeMassDataIntegratorToRt &other);
+    const ProcessingFlow &processing_flow,
+    QObject *parent = nullptr);
 
   virtual ~MsRunDataSetTreeMassDataIntegratorToRt();
 
-  ProcessingFlow getProcessingFlow() const;
+  MassDataIntegrator *clone(QObject *parent = nullptr) const;
 
   const MsRunDataSetStats &getMsRunDataSetStats() const;
 
@@ -103,12 +95,6 @@ class MsRunDataSetTreeMassDataIntegratorToRt : public MassDataIntegrator
   MsRunDataSetStats m_msRunDataSetStats;
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
-
-Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRt)
-extern int msRunDataSetTreeMassDataIntegratorMetaTypeId;
-
-Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr)
-extern int msRunDataSetTreeMassDataIntegratorSPtrMetaTypeId;
