@@ -123,7 +123,7 @@ MsRunStatisticsTreeNodeVisitor::visit(const pappso::MsRunDataSetTreeNode &node)
 
   if(qualified_mass_spectrum_csp == nullptr)
     {
-      qFatal("Failed to read the mass spectral data from the file.");
+      qFatal() << "Failed to read the mass spectral data from the file.";
     }
 
   // qDebug().noquote() << "Visiting qualified mass spectrum:"
