@@ -40,7 +40,6 @@
 /////////////////////// Qt includes
 #include <QString>
 #include <QDateTime>
-#include <QtQml>
 
 
 /////////////////////// pappsomspp includes
@@ -51,7 +50,7 @@
 /////////////////////// libXpertMass includes
 // For MSXPS_REGISTER_JS_CLASS(NS_IDENT, CLASS_NAME)
 // At the end of the file.
-#include <MsXpS/libXpertMassGui/ScriptingEnginesBridge.hpp>
+#include <MsXpS/libXpertMassCore/jsclassregistrar.h>
 
 
 /////////////////////// Local includes
@@ -75,7 +74,7 @@ class ProcessingFlow: public QObject
   public:
   Q_INVOKABLE explicit ProcessingFlow(QObject *parent = nullptr);
   Q_INVOKABLE explicit ProcessingFlow(MsRunDataSetCstSPtr ms_run_data_set_csp,
-                             QObject *parent = nullptr);
+                                      QObject *parent = nullptr);
 
   virtual ~ProcessingFlow();
 
@@ -118,7 +117,7 @@ class ProcessingFlow: public QObject
                  std::pair<double, double> &out_range,
                  std::vector<ProcessingStepCstSPtr> *out_processing_steps_p,
                  bool store_only_2d_steps = true,
-                 bool store_only_rhomboid   = true) const;
+                 bool store_only_rhomboid = true) const;
 
   bool innermostRange(
     const QString src_processing_type_mask,
