@@ -41,8 +41,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/processing/combiners/massspectrumpluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -50,17 +50,11 @@
 #include "MsRunDataSet.hpp"
 #include "ProcessingFlow.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-class QualifiedMassSpectrumVectorMassDataIntegrator;
-
-typedef std::shared_ptr<QualifiedMassSpectrumVectorMassDataIntegrator>
-  QualifiedMassSpectrumVectorMassDataIntegratorSPtr;
-
 typedef std::vector<pappso::QualifiedMassSpectrumCstSPtr>
   QualifiedMassSpectraVector;
 
@@ -70,27 +64,32 @@ typedef std::shared_ptr<QualifiedMassSpectraVector>
 typedef std::shared_ptr<const QualifiedMassSpectraVector>
   QualifiedMassSpectraVectorCstSPtr;
 
-class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
+class QualifiedMassSpectrumVectorMassDataIntegrator: public QObject
 {
   Q_OBJECT
 
   public:
-  QualifiedMassSpectrumVectorMassDataIntegrator();
+  QualifiedMassSpectrumVectorMassDataIntegrator(QObject *parent = nullptr);
 
   QualifiedMassSpectrumVectorMassDataIntegrator(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp);
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent = nullptr);
 
-  QualifiedMassSpectrumVectorMassDataIntegrator(
-    const QualifiedMassSpectrumVectorMassDataIntegrator &other);
 
   virtual ~QualifiedMassSpectrumVectorMassDataIntegrator();
 
+  virtual QualifiedMassSpectrumVectorMassDataIntegrator *
+  clone(QObject *parent = nullptr) const = 0;
+
   MsRunDataSetCstSPtr getMsRunDataSet() const;
 
   void setProcessingFlow(const ProcessingFlow &processing_flow);
-  const ProcessingFlow &getProcessingFlow() const;
+  const ProcessingFlow &getProcessingFlowCstRef() const;
+  ProcessingFlow &getProcessingFlowRef();
+  ProcessingFlow *getProcessingFlow();
 
   virtual pappso::QualifiedMassSpectrumCstSPtr checkQualifiedMassSpectrum(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
@@ -135,7 +134,7 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
   protected:
   MsRunDataSetCstSPtr mcsp_msRunDataSet = nullptr;
 
-  ProcessingFlow m_processingFlow;
+  ProcessingFlow *mp_processingFlow;
 
   std::size_t m_maxThreadUseCount = 0;
 
@@ -186,7 +185,6 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
   virtual bool checkDtRange(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
 
-  protected:
   // We almost systematically need these m/z range values when making visits:
   // one criterium might be that the m/z value of data points (the x member of
   // DataPoint) be contained within the limit m/z range.
@@ -208,20 +206,9 @@ class QualifiedMassSpectrumVectorMassDataIntegrator : public QObject
 
   bool checkInnermostDtRt2DSteps(
     pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp);
-
-  private:
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
-
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorMetaTypeId;
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorSPtrMetaTypeId;
