@@ -68,7 +68,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::
   QualifiedMassSpectrumVectorMassDataIntegratorToDt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    const QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp,
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
     QObject *parent)
   : QualifiedMassSpectrumVectorMassDataIntegrator(
       ms_run_data_set_csp,
@@ -134,7 +135,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
   // from which to find the specifics of the calculation.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   // When constructing this integrator, the processing flow passed as parameter
   // was used to gather innermost ranges data. When the steps that match
@@ -412,7 +413,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
               // m_mzRange. So we can account that limit right away.
 
               if(std::isnan(m_mzRange.first) || std::isnan(m_mzRange.second))
-                qFatal("Programming error.");
+                qFatal() << "Programming error.";
 
               // qDebug() << "m_mzRange.first:" << m_mzRange.first
               //          << "m_mzRange.second:" << m_mzRange.second;
