@@ -41,7 +41,7 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/trace/maptrace.h>
+#include <pappsomspp/core/trace/maptrace.h>
 
 
 /////////////////////// Local includes
@@ -49,10 +49,9 @@
 #include "ProcessingFlow.hpp"
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 class QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz;
@@ -70,19 +69,23 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz
   Q_OBJECT
 
   public:
-  QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz();
+  QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz(
+    QObject *parent = nullptr);
 
   QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp);
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent = nullptr);
 
-  QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz &other);
 
   virtual ~QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz();
 
-  pappso::DataKind getLastIntegrationDataKind() const;
+  QualifiedMassSpectrumVectorMassDataIntegrator *
+  clone(QObject *parent) const override;
+
+  pappso::Enums::DataKind getLastIntegrationDataKind() const;
 
   std::size_t getColorMapKeyCellCount() const;
   std::size_t getColorMapMzCellCount() const;
@@ -96,15 +99,12 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz
   using Map = std::map<double, pappso::MapTrace>;
   const std::shared_ptr<Map> &getDoubleMapTraceMapSPtr() const;
 
-
   public slots:
 
   void integrate();
   virtual void integrateNoBinning();
   virtual void integrateArbitraryBinning();
 
-  signals:
-
   protected:
   std::size_t m_colorMapKeyCellCount = 0;
   std::size_t m_colorMapMzCellCount  = 0;
@@ -117,18 +117,9 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz
 
   std::shared_ptr<Map> m_doubleMapTraceMapSPtr = nullptr;
 
-  pappso::DataKind m_lastIntegrationDataKind;
+  pappso::Enums::DataKind m_lastIntegrationDataKind;
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
-
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzMetaTypeId;
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtr)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtrMetaTypeId;
