@@ -100,7 +100,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::clone(QObject *parent) const
 
   copy_p->m_maxThreadUseCount = m_maxThreadUseCount;
   copy_p->m_innermostSteps2D.assign(m_innermostSteps2D.begin(),
-                                  m_innermostSteps2D.end());
+                                    m_innermostSteps2D.end());
   copy_p->m_dtRange = m_dtRange;
   copy_p->m_mzRange = m_mzRange;
   copy_p->m_rtRange = m_rtRange;
@@ -124,8 +124,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrate()
   pappso::MzIntegrationParams *mz_integration_params_p =
     mp_processingFlow->getSensibleMzIntegrationParams();
 
-    // qDebug().noquote() << "20250904 - Got sensible mz integration params:"
-    // << mz_integration_params_p->toString();
+  // qDebug().noquote() << "Got sensible mz integration params:"
+  // << mz_integration_params_p->toString();
 
   if(mz_integration_params_p->getBinningType() ==
      pappso::MzIntegrationParams::BinningType::NONE)
@@ -183,7 +183,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   // from which to find the specifics of the calculation.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   // When constructing this integrator, the processing flow passed as parameter
   // was used to gather innermost ranges data. When the steps that match
@@ -550,8 +550,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   std::size_t mass_spectra_count =
     mcsp_qualifiedMassSpectraToIntegrateVector->size();
 
-    qDebug() << "20250904 - Integration in arbitrary binning mode of"
-    << mass_spectra_count << "spectr[um,a].";
+  qDebug() << "Integration in arbitrary binning mode of" << mass_spectra_count
+           << "spectr[um,a].";
 
   if(!mass_spectra_count)
     {
@@ -572,7 +572,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // from which to find the specifics of the calculation.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   // In this case where binning is requested, we need to craft the bins, and for
   // that we need proper mz integration params.
@@ -581,16 +581,16 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   pappso::MzIntegrationParams *sensible_mz_integration_params_p =
     mp_processingFlow->getSensibleMzIntegrationParams();
 
-  qDebug().noquote() << "20250904 - Sensible MzIntegrationParams:"
-           << sensible_mz_integration_params_p->toString(0, "  ");
+  qDebug().noquote() << "Sensible MzIntegrationParams:"
+                     << sensible_mz_integration_params_p->toString(0, "  ");
 
-  qDebug().noquote() << "20250904 - The ms run data set stats:"
-  << mcsp_msRunDataSet->getMsRunDataSetStats().toString();
+  qDebug().noquote() << "The ms run data set stats:"
+                     << mcsp_msRunDataSet->getMsRunDataSetStats().toString();
 
   // Now we can create the bins!
   std::vector<double> bins = sensible_mz_integration_params_p->createBins();
 
-  qDebug() << "20250904 - The bins were created, count:" << bins.size();
+  qDebug() << "The bins were created, count:" << bins.size();
 
 #if 0
   QString bins_before = "Bins:\n";
@@ -658,7 +658,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   if(bins_before == bins_after)
     qDebug() << "The copying of the bins in the template combiner worked.";
   else
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
 #endif
 
@@ -809,7 +809,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
           if(!std::isnan(m_mzRange.first) && !std::isnan(m_mzRange.second))
             {
               qDebug() << "There is a mz range for the integration:"
-              << "[" << m_mzRange.first << "-" << m_mzRange.second << "]";
+                       << "[" << m_mzRange.first << "-" << m_mzRange.second
+                       << "]";
 
               filtered_trace.initialize(
                 *qualified_mass_spectrum_csp->getMassSpectrumSPtr());
@@ -965,7 +966,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
     }
 
   // Write the data to file so that we can check. It works !!!
-  pappso::Utils::appendToFile(m_mapTrace.toString(), "/tmp/prova.txt");
+  // pappso::Utils::appendToFile(m_mapTrace.toString(), "/tmp/prova.txt");
 
   // At this point, we have really combined all the traces into a single map
   // trace!
