@@ -137,7 +137,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRt::integrate()
   // from which to find the specifics of the calculation.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   // When constructing this integrator, the processing flow passed as parameter
   // was used to gather innermost ranges data. When the steps that match
@@ -316,7 +316,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRt::integrate()
               // for in m_mzRange. So we can account that limit right away.
 
               if(std::isnan(m_mzRange.first) || std::isnan(m_mzRange.second))
-                qFatal("Programming error.");
+                qFatal() << "Programming error.";
 
               pappso::Trace filtered_trace(
                 *qualified_mass_spectrum_csp->getMassSpectrumSPtr());
