@@ -41,8 +41,8 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/processing/combiners/massspectrumpluscombiner.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/processing/combiners/massspectrumpluscombiner.h>
 
 
 /////////////////////// Local includes
@@ -51,58 +51,37 @@
 #include "ProcessingFlow.hpp"
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-class QualifiedMassSpectrumVectorMassDataIntegratorToRt;
-
-typedef std::shared_ptr<QualifiedMassSpectrumVectorMassDataIntegratorToRt>
-  QualifiedMassSpectrumVectorMassDataIntegratorToRtSPtr;
-
-typedef std::shared_ptr<const QualifiedMassSpectrumVectorMassDataIntegratorToRt>
-  QualifiedMassSpectrumVectorMassDataIntegratorToRtCstSPtr;
-
 class QualifiedMassSpectrumVectorMassDataIntegratorToRt
   : public QualifiedMassSpectrumVectorMassDataIntegrator
 {
   Q_OBJECT
 
   public:
-  QualifiedMassSpectrumVectorMassDataIntegratorToRt();
+  QualifiedMassSpectrumVectorMassDataIntegratorToRt(QObject *parent = nullptr);
 
   QualifiedMassSpectrumVectorMassDataIntegratorToRt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp);
-
-  QualifiedMassSpectrumVectorMassDataIntegratorToRt(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToRt &other);
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent = nullptr);
 
   virtual ~QualifiedMassSpectrumVectorMassDataIntegratorToRt();
 
+  QualifiedMassSpectrumVectorMassDataIntegrator *
+  clone(QObject *parent) const override;
+
   public slots:
 
   void integrate();
-
-  signals:
-
-  protected:
-  private:
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
-
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRt)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToRtMetaTypeId;
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtSPtr)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToRtSPtrMetaTypeId;
