@@ -67,7 +67,8 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToRtDt
   QualifiedMassSpectrumVectorMassDataIntegratorToRtDt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    const QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp,
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
     QObject *parent = nullptr);
 
   virtual ~QualifiedMassSpectrumVectorMassDataIntegratorToRtDt();
