@@ -144,7 +144,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
   // from which to find the specifics of the calculation.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   // Get the most recent step that holds all the specifics of this integration.
   ProcessingStepCstSPtr most_recent_processing_step_csp =
@@ -152,7 +152,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
 
   if(!most_recent_processing_step_csp->getDestProcessingType().bitMatches(
        "INT"))
-    qFatal("There should be one ProcessingType = INT. Program aborted.");
+    qFatal() << "There should be one ProcessingType = INT. Program aborted.";
 
   // When constructing this integrator, the processing flow passed as parameter
   // was used to gather innermost ranges data. When the steps that match
@@ -329,7 +329,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToTicInt::integrate()
               // m_mzRange. So we can account that limit right away.
 
               if(std::isnan(m_mzRange.first) || std::isnan(m_mzRange.second))
-                qFatal("Programming error.");
+                qFatal() << "Programming error.";
 
               pappso::Trace filtered_trace(
                 *qualified_mass_spectrum_csp->getMassSpectrumSPtr());
