@@ -41,7 +41,7 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/trace/maptrace.h>
+#include <pappsomspp/core/trace/maptrace.h>
 
 
 /////////////////////// Local includes
@@ -49,61 +49,43 @@
 #include "ProcessingFlow.hpp"
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
-class QualifiedMassSpectrumVectorMassDataIntegratorToTicInt;
-
-typedef std::shared_ptr<QualifiedMassSpectrumVectorMassDataIntegratorToTicInt>
-  QualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtr;
-
-typedef std::shared_ptr<
-  const QualifiedMassSpectrumVectorMassDataIntegratorToTicInt>
-  QualifiedMassSpectrumVectorMassDataIntegratorToTicIntCstSPtr;
-
-
 class QualifiedMassSpectrumVectorMassDataIntegratorToTicInt
   : public QualifiedMassSpectrumVectorMassDataIntegrator
 {
   Q_OBJECT
 
   public:
-  QualifiedMassSpectrumVectorMassDataIntegratorToTicInt();
+  QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
+    QObject *parent = nullptr);
 
   QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
     MsRunDataSetCstSPtr ms_run_data_set_csp,
     const ProcessingFlow &processing_flow,
-    QualifiedMassSpectraVectorSPtr &qualified_mass_spectra_to_integrate_sp);
+    const QualifiedMassSpectraVectorSPtr
+      &qualified_mass_spectra_to_integrate_sp,
+    QObject *parent = nullptr);
 
-  QualifiedMassSpectrumVectorMassDataIntegratorToTicInt(
-    const QualifiedMassSpectrumVectorMassDataIntegratorToTicInt &other);
 
   virtual ~QualifiedMassSpectrumVectorMassDataIntegratorToTicInt();
 
+  QualifiedMassSpectrumVectorMassDataIntegrator *
+  clone(QObject *parent) const override;
+
   double getTicIntensity() const;
 
   public slots:
 
   void integrate();
 
-  signals:
-
   protected:
   double m_ticIntensity = 0.0;
 };
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
-
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicInt)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToTicIntMetaTypeId;
-
-Q_DECLARE_METATYPE(
-  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtr)
-extern int qualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtrMetaTypeId;
