@@ -50,7 +50,6 @@
 ////////////////////////////// Local includes
 #include "globals.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -93,7 +92,6 @@ QRegularExpression gXyFormatMassDataRegExp =
 //! Regular expression that tracks the end of line in text files.
 QRegularExpression gEndOfLineRegExp = QRegularExpression("^\\s+$");
 
-
 //! Return the average of the double list. Also fill-in the variance and
 //! standard deviation if the parameters are non-nullptr.
 void
@@ -111,7 +109,7 @@ doubleVectorStatistics(std::vector<double> &vector,
      stdDeviation == Q_NULLPTR || nonZeroSmallest == Q_NULLPTR ||
      smallest == Q_NULLPTR || greatest == Q_NULLPTR ||
      smallestMedian == Q_NULLPTR)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // Sort the vector, we'll need it sorted to compute the median value.
   std::sort(vector.begin(), vector.end());
@@ -131,8 +129,8 @@ doubleVectorStatistics(std::vector<double> &vector,
 
   for(auto &&value : vector)
     {
-      double current = value;
-      *sum += current;
+      double current  = value;
+      *sum           += current;
 
       // If current is non-zero, then take its value into account.
       if(current > 0 && current < *nonZeroSmallest)
@@ -168,7 +166,6 @@ doubleVectorStatistics(std::vector<double> &vector,
     }
 }
 
-
 //! Tell if both double values, are equal within the double representation
 //! capabilities of the platform.
 bool
@@ -214,7 +211,6 @@ almostEqual(double value1, double value2, int decimalPlaces)
   return res;
 }
 
-
 //! Provides a text stream handle to the standard output.
 /*!
  * Use:   msXpS::qStdOut() << "text to the standard output,"
@@ -230,7 +226,6 @@ qStdOut()
   return ts;
 }
 
-
 //! Remove all space characters from a string.
 /*!
  * \param text reference to the string
@@ -244,12 +239,12 @@ unspacifyString(QString &text)
       return text;
     }
 
-  text.remove(QRegularExpression("\\s+"));
+  static QRegularExpression regexp("\\s+");
+  text.remove(regexp);
 
   return text;
 }
 
-
 //! Produce a binary representation of an int
 /*!
  * \param value int value
@@ -264,8 +259,6 @@ binaryRepresentation(int value)
   return string;
 }
 
-
-
 //! Determine the number of zero decimals between the decimal point and the
 //! first non-zero decimal.
 /*!
@@ -300,7 +293,6 @@ zeroDecimals(double value)
   return count;
 }
 
-
 //! Return the delta corresponding to m/z \p value and \p ppm part-per-million
 double
 ppm(double value, double ppm)
@@ -309,7 +301,6 @@ ppm(double value, double ppm)
   return (value * ppm) / 1000000;
 }
 
-
 //! Return \p value incremented with the matching \p ppm part.
 double
 addPpm(double value, double ppm)
@@ -318,7 +309,6 @@ addPpm(double value, double ppm)
   return value + (value * ppm) / 1000000;
 }
 
-
 //! Return \p value decremented with the matching \p ppm part.
 double
 removePpm(double value, double ppm)
@@ -327,7 +317,6 @@ removePpm(double value, double ppm)
   return value - (value * ppm) / 1000000;
 }
 
-
 //! Return the delta corresponding to m/z \p value and resolution \p res
 double
 res(double value, double res)
@@ -335,7 +324,6 @@ res(double value, double res)
   return value / res;
 }
 
-
 //! Return \p value incremented with the matching \p res part.
 double
 addRes(double value, double res)
@@ -350,7 +338,6 @@ removeRes(double value, double res)
   return value - (value / res);
 }
 
-
 //! Craft a string representing the address location (for debugging).
 QString
 pointerAsString(void *pointer)
